@@ -14,7 +14,7 @@ import sys
 import tempfile
 import time
 from pathlib import Path
-from typing import Any, Dict, List
+from typing import Any
 
 import psutil
 
@@ -38,9 +38,10 @@ class PerformanceBenchmark:
         ]
 
         for path in possible_paths:
-            if os.path.exists(path):
-                return path
-            elif subprocess.run(["which", path], capture_output=True).returncode == 0:
+            if (
+                os.path.exists(path)
+                or subprocess.run(["which", path], capture_output=True, check=False).returncode == 0
+            ):
                 return path
 
         raise FileNotFoundError("Riveter binary not found")
@@ -48,17 +49,19 @@ class PerformanceBenchmark:
     def _find_python_path(self) -> str:
         """Find the Python installation path."""
         # Check if we can run riveter via Python module
-        result = subprocess.run([sys.executable, "-c", "import riveter.cli"], capture_output=True)
+        result = subprocess.run(
+            [sys.executable, "-c", "import riveter.cli"], capture_output=True, check=False
+        )
         if result.returncode == 0:
             return sys.executable
 
         raise FileNotFoundError("Python Riveter installation not found")
 
-    def run_binary_command(self, args: List[str], measure_memory: bool = False) -> Dict[str, Any]:
+    def run_binary_command(self, args: list[str], measure_memory: bool = False) -> dict[str, Any]:
         """Run a command with the binary and measure performance."""
         return self._run_command([self.binary_path] + args, measure_memory)
 
-    def run_python_command(self, args: List[str], measure_memory: bool = False) -> Dict[str, Any]:
+    def run_python_command(self, args: list[str], measure_memory: bool = False) -> dict[str, Any]:
         """Run a command with Python and measure performance."""
         env = os.environ.copy()
         env["PYTHONPATH"] = str(Path(__file__).parent.parent / "src")
@@ -68,8 +71,8 @@ class PerformanceBenchmark:
         )
 
     def _run_command(
-        self, cmd: List[str], measure_memory: bool = False, env: Dict = None
-    ) -> Dict[str, Any]:
+        self, cmd: list[str], measure_memory: bool = False, env: dict = None
+    ) -> dict[str, Any]:
         """Run a command and measure its performance."""
         start_time = time.time()
 
@@ -99,7 +102,7 @@ class PerformanceBenchmark:
                 returncode = process.returncode
         else:
             # Simple execution without memory monitoring
-            result = subprocess.run(cmd, capture_output=True, text=True, env=env)
+            result = subprocess.run(cmd, capture_output=True, text=True, env=env, check=False)
             stdout = result.stdout
             stderr = result.stderr
             returncode = result.returncode
@@ -116,7 +119,7 @@ class PerformanceBenchmark:
             "stderr": stderr,
         }
 
-    def benchmark_startup_time(self, iterations: int = 10) -> Dict[str, Any]:
+    def benchmark_startup_time(self, iterations: int = 10) -> dict[str, Any]:
         """Benchmark startup time for --version command."""
         print("Benchmarking startup time...")
 
@@ -158,7 +161,7 @@ class PerformanceBenchmark:
             ),
         }
 
-    def benchmark_memory_usage(self) -> Dict[str, Any]:
+    def benchmark_memory_usage(self) -> dict[str, Any]:
         """Benchmark memory usage for various commands."""
         print("Benchmarking memory usage...")
 
@@ -188,7 +191,7 @@ class PerformanceBenchmark:
 
         return results
 
-    def benchmark_terraform_processing(self, iterations: int = 5) -> Dict[str, Any]:
+    def benchmark_terraform_processing(self, iterations: int = 5) -> dict[str, Any]:
         """Benchmark Terraform file processing performance."""
         print("Benchmarking Terraform processing...")
 
@@ -252,7 +255,7 @@ class PerformanceBenchmark:
 
         return results
 
-    def _create_test_terraform_files(self) -> Dict[str, Path]:
+    def _create_test_terraform_files(self) -> dict[str, Path]:
         """Create test Terraform files of different sizes."""
         test_files = {}
 
@@ -320,7 +323,7 @@ resource "aws_instance" "large_test_{i}" {{
 
         return test_files
 
-    def benchmark_rule_pack_loading(self) -> Dict[str, Any]:
+    def benchmark_rule_pack_loading(self) -> dict[str, Any]:
         """Benchmark rule pack loading performance."""
         print("Benchmarking rule pack loading...")
 
@@ -389,7 +392,7 @@ resource "aws_instance" "test" {
 
         return results
 
-    def run_full_benchmark(self) -> Dict[str, Any]:
+    def run_full_benchmark(self) -> dict[str, Any]:
         """Run the complete benchmark suite."""
         print("Starting comprehensive performance benchmark...")
         print(f"Binary path: {self.binary_path}")
@@ -415,7 +418,7 @@ resource "aws_instance" "test" {
 
         return results
 
-    def generate_report(self, results: Dict[str, Any]) -> str:
+    def generate_report(self, results: dict[str, Any]) -> str:
         """Generate a human-readable benchmark report."""
         report = []
         report.append("# Riveter Binary vs Python Performance Benchmark Report")
