@@ -21,11 +21,11 @@ import hashlib
 import logging
 import os
 import platform
+import re
 import shutil
 import subprocess
 import sys
 from pathlib import Path
-from typing import List, Optional, Tuple
 
 # Configure logging
 logging.basicConfig(
@@ -80,17 +80,14 @@ class BinaryBuilder:
         if system == "darwin":
             if machine in ["x86_64", "amd64"]:
                 return "macos-intel"
-            elif machine in ["arm64", "aarch64"]:
+            if machine in ["arm64", "aarch64"]:
                 return "macos-arm64"
-            else:
-                raise ValueError(f"Unsupported macOS architecture: {machine}")
-        elif system == "linux":
+            raise ValueError(f"Unsupported macOS architecture: {machine}")
+        if system == "linux":
             if machine in ["x86_64", "amd64"]:
                 return "linux-x86_64"
-            else:
-                raise ValueError(f"Unsupported Linux architecture: {machine}")
-        else:
-            raise ValueError(f"Unsupported operating system: {system}")
+            raise ValueError(f"Unsupported Linux architecture: {machine}")
+        raise ValueError(f"Unsupported operating system: {system}")
 
     def validate_environment(self) -> None:
         """Validate that the build environment is properly set up.
@@ -161,7 +158,7 @@ src_dir = project_root / "src"
 sys.path.insert(0, str(src_dir))
 
 # Import and run main
-from riveter.cli import main
+from riveter.cli.main import main
 
 if __name__ == "__main__":
     main()
@@ -172,7 +169,7 @@ if __name__ == "__main__":
 
         return entry_script
 
-    def get_hidden_imports(self) -> List[str]:
+    def get_hidden_imports(self) -> list[str]:
         """Get list of hidden imports for PyInstaller.
 
         Returns:
@@ -203,6 +200,15 @@ if __name__ == "__main__":
             # Third-party dependencies that might need explicit inclusion
             "yaml",
             "hcl2",
+            "hcl2.parser",
+            "hcl2.api",
+            "lark",
+            "lark.parsers",
+            "lark.parsers.lalr_parser",
+            "lark.lexer",
+            "lark.grammar",
+            "lark.common",
+            "lark.tree",
             "click",
             "rich",
             "cryptography",
@@ -227,7 +233,7 @@ if __name__ == "__main__":
         logger.debug(f"Hidden imports: {hidden_imports}")
         return hidden_imports
 
-    def get_data_files(self) -> List[tuple[str, str]]:
+    def get_data_files(self) -> list[tuple[str, str]]:
         """Get list of data files to include in the binary.
 
         Returns:
@@ -241,12 +247,54 @@ if __name__ == "__main__":
                 data_files.append((str(rule_pack), "rule_packs"))
                 logger.debug(f"Including rule pack: {rule_pack}")
 
+        # Include HCL parser grammar files
+        try:
+            import hcl2
+
+            hcl2_path = Path(hcl2.__file__).parent
+            hcl2_lark = hcl2_path / "hcl2.lark"
+            if hcl2_lark.exists():
+                data_files.append((str(hcl2_lark), "hcl2"))
+                logger.debug(f"Including HCL grammar file: {hcl2_lark}")
+            else:
+                logger.warning(f"HCL grammar file not found at {hcl2_lark}")
+        except ImportError:
+            logger.warning("hcl2 module not found, HCL parsing may not work in binary")
+
         # Include any other static assets
         # Add more data files here as needed
 
         logger.debug(f"Data files: {data_files}")
         return data_files
 
+    def _update_version_file(self, version: str) -> None:
+        """Update the _version.py file with the specified version.
+
+        Args:
+            version: Version string to set
+        """
+        version_file = self.project_root / "src" / "riveter" / "_version.py"
+        if not version_file.exists():
+            logger.warning(f"Version file not found: {version_file}")
+            return
+
+        try:
+            with open(version_file) as f:
+                content = f.read()
+
+            # Update the __version__ variable
+            updated_content = re.sub(
+                r'(__version__\s*=\s*["\'])[\d.]+(["\'])', f"\\g<1>{version}\\g<2>", content
+            )
+
+            with open(version_file, "w") as f:
+                f.write(updated_content)
+
+            logger.info(f"Updated version in _version.py to {version}")
+
+        except Exception as e:
+            logger.warning(f"Failed to update _version.py: {e}")
+
     def generate_spec_file(self, target_platform: str) -> Path:
         """Generate PyInstaller spec file for the target platform.
 
@@ -303,9 +351,9 @@ if __name__ == "__main__":
             "--noconfirm",
         ]
 
-        if self.debug:
-            cmd.append("--debug=all")
-        else:
+        # Note: --debug flag is not compatible with spec files
+        # Debug information is controlled by the spec file itself
+        if not self.debug:
             cmd.append("--log-level=INFO")
 
         cmd.append(str(spec_file))
@@ -493,8 +541,8 @@ if __name__ == "__main__":
             raise RuntimeError(f"Failed to read version from pyproject.toml: {e}") from e
 
     def create_archive_with_checksum(
-        self, binary_path: Path, target_platform: str, version: Optional[str] = None
-    ) -> Tuple[Path, str]:
+        self, binary_path: Path, target_platform: str, version: str | None = None
+    ) -> tuple[Path, str]:
         """Create a tar.gz archive of the binary with SHA256 checksum.
 
         Args:
@@ -561,9 +609,9 @@ if __name__ == "__main__":
 
     def build(
         self,
-        target_platform: Optional[str] = None,
+        target_platform: str | None = None,
         create_archive: bool = False,
-        version: Optional[str] = None,
+        version: str | None = None,
     ) -> Path:
         """Build the binary for the specified or detected platform.
 
@@ -596,6 +644,10 @@ if __name__ == "__main__":
         # Clean previous builds
         self.clean_build_artifacts()
 
+        # Update version in _version.py if version is provided
+        if version:
+            self._update_version_file(version)
+
         # Generate spec file
         spec_file = self.generate_spec_file(target_platform)
 
@@ -697,7 +749,7 @@ Supported platforms:
             checksum_file = result_path.with_suffix(result_path.suffix + ".sha256")
             if checksum_file.exists():
                 print(f"🔐 Checksum file: {checksum_file}")
-                with open(checksum_file, "r") as f:
+                with open(checksum_file) as f:
                     print(f"🔐 SHA256: {f.read().strip().split()[0]}")
         else:
             print(f"📦 Binary location: {result_path}")
