@@ -17,7 +17,6 @@ import time
 from dataclasses import dataclass
 from enum import Enum
 from pathlib import Path
-from typing import Dict, List, Optional
 
 # Configure logging
 logging.basicConfig(
@@ -45,8 +44,8 @@ class RecoveryAction:
 
     name: str
     description: str
-    command: Optional[str] = None
-    function: Optional[callable] = None
+    command: str | None = None
+    function: callable | None = None
     retry_count: int = 1
     delay: float = 0.0
 
@@ -57,17 +56,17 @@ class ErrorDiagnostic:
 
     error_type: ErrorType
     error_message: str
-    exit_code: Optional[int] = None
-    stdout: Optional[str] = None
-    stderr: Optional[str] = None
-    environment: Optional[Dict[str, str]] = None
-    recovery_actions: List[RecoveryAction] = None
+    exit_code: int | None = None
+    stdout: str | None = None
+    stderr: str | None = None
+    environment: dict[str, str] | None = None
+    recovery_actions: list[RecoveryAction] = None
 
 
 class HomebrewErrorRecovery:
     """Handles error recovery for Homebrew installation issues."""
 
-    def __init__(self, project_root: Optional[Path] = None, debug: bool = False):
+    def __init__(self, project_root: Path | None = None, debug: bool = False):
         """Initialize error recovery handler.
 
         Args:
@@ -98,18 +97,17 @@ class HomebrewErrorRecovery:
 
         if "tap" in error_lower and ("not found" in error_lower or "does not exist" in error_lower):
             return self._diagnose_tap_error(error_output, exit_code)
-        elif "audit" in error_lower or "formula" in error_lower:
+        if "audit" in error_lower or "formula" in error_lower:
             return self._diagnose_formula_error(error_output, exit_code)
-        elif "install" in error_lower and ("failed" in error_lower or "error" in error_lower):
+        if "install" in error_lower and ("failed" in error_lower or "error" in error_lower):
             return self._diagnose_installation_error(error_output, exit_code)
-        elif "version" in error_lower and "mismatch" in error_lower:
+        if "version" in error_lower and "mismatch" in error_lower:
             return self._diagnose_version_error(error_output, exit_code)
-        elif "network" in error_lower or "connection" in error_lower or "timeout" in error_lower:
+        if "network" in error_lower or "connection" in error_lower or "timeout" in error_lower:
             return self._diagnose_network_error(error_output, exit_code)
-        elif "permission" in error_lower or "denied" in error_lower:
+        if "permission" in error_lower or "denied" in error_lower:
             return self._diagnose_permissions_error(error_output, exit_code)
-        else:
-            return self._diagnose_generic_error(error_output, exit_code)
+        return self._diagnose_generic_error(error_output, exit_code)
 
     def _diagnose_tap_error(self, error_output: str, exit_code: int) -> ErrorDiagnostic:
         """Diagnose tap installation errors."""
@@ -359,8 +357,7 @@ class HomebrewErrorRecovery:
                     if success:
                         logger.info(f"✅ Recovery action {action.name} succeeded")
                         break
-                    else:
-                        logger.warning(f"❌ Recovery action {action.name} failed")
+                    logger.warning(f"❌ Recovery action {action.name} failed")
 
                 except Exception as e:
                     logger.error(f"❌ Recovery action {action.name} failed with exception: {e}")
@@ -388,7 +385,8 @@ class HomebrewErrorRecovery:
                 shell=True,
                 capture_output=True,
                 text=True,
-                timeout=300,  # 5 minute timeout
+                timeout=300,
+                check=False,  # 5 minute timeout
             )
 
             if result.returncode == 0:
@@ -396,11 +394,10 @@ class HomebrewErrorRecovery:
                 if result.stdout:
                     logger.debug(f"stdout: {result.stdout}")
                 return True
-            else:
-                logger.warning(f"Command failed with exit code {result.returncode}: {command}")
-                if result.stderr:
-                    logger.warning(f"stderr: {result.stderr}")
-                return False
+            logger.warning(f"Command failed with exit code {result.returncode}: {command}")
+            if result.stderr:
+                logger.warning(f"stderr: {result.stderr}")
+            return False
 
         except subprocess.TimeoutExpired:
             logger.error(f"Command timed out: {command}")
@@ -418,6 +415,7 @@ class HomebrewErrorRecovery:
                 ["brew", "untap", "scottryanhoward/homebrew-riveter"],
                 capture_output=True,
                 timeout=60,
+                check=False,
             )
 
             # Add tap
@@ -426,6 +424,7 @@ class HomebrewErrorRecovery:
                 capture_output=True,
                 text=True,
                 timeout=120,
+                check=False,
             )
 
             return result.returncode == 0
@@ -462,6 +461,7 @@ class HomebrewErrorRecovery:
                 capture_output=True,
                 text=True,
                 timeout=30,
+                check=False,
             )
 
             return result.returncode == 0
@@ -504,11 +504,11 @@ class HomebrewErrorRecovery:
                     capture_output=True,
                     text=True,
                     timeout=120,
+                    check=False,
                 )
                 return result.returncode == 0
-            else:
-                logger.warning("Version sync script not found")
-                return False
+            logger.warning("Version sync script not found")
+            return False
 
         except Exception as e:
             logger.error(f"Formula checksum update failed: {e}")
@@ -522,6 +522,7 @@ class HomebrewErrorRecovery:
                 ["brew", "uninstall", "scottryanhoward/homebrew-riveter/riveter"],
                 capture_output=True,
                 timeout=60,
+                check=False,
             )
 
             # Install
@@ -530,6 +531,7 @@ class HomebrewErrorRecovery:
                 capture_output=True,
                 text=True,
                 timeout=300,
+                check=False,
             )
 
             return result.returncode == 0
@@ -547,16 +549,16 @@ class HomebrewErrorRecovery:
                 capture_output=True,
                 text=True,
                 timeout=120,
+                check=False,
             )
 
             # brew doctor returns 0 if no issues, 1 if warnings/errors
             if result.returncode == 0:
                 logger.info("No dependency issues found")
                 return True
-            else:
-                logger.warning(f"Dependency issues detected: {result.stdout}")
-                # Could implement specific fixes based on output
-                return False
+            logger.warning(f"Dependency issues detected: {result.stdout}")
+            # Could implement specific fixes based on output
+            return False
 
         except Exception as e:
             logger.error(f"Dependency check failed: {e}")
@@ -572,11 +574,11 @@ class HomebrewErrorRecovery:
                     capture_output=True,
                     text=True,
                     timeout=120,
+                    check=False,
                 )
                 return result.returncode == 0
-            else:
-                logger.warning("Version sync script not found")
-                return False
+            logger.warning("Version sync script not found")
+            return False
 
         except Exception as e:
             logger.error(f"Version sync failed: {e}")
@@ -592,11 +594,11 @@ class HomebrewErrorRecovery:
                     capture_output=True,
                     text=True,
                     timeout=60,
+                    check=False,
                 )
                 return result.returncode == 0
-            else:
-                logger.warning("Version sync script not found")
-                return False
+            logger.warning("Version sync script not found")
+            return False
 
         except Exception as e:
             logger.error(f"Version validation failed: {e}")
@@ -664,6 +666,7 @@ class HomebrewErrorRecovery:
                 capture_output=True,
                 text=True,
                 timeout=120,
+                check=False,
             )
 
             # If brew doctor suggests fixes, those would be implemented here
@@ -822,7 +825,7 @@ def main():
         if args.diagnose == "-":
             error_output = sys.stdin.read()
         else:
-            with open(args.diagnose, "r") as f:
+            with open(args.diagnose) as f:
                 error_output = f.read()
 
         # Diagnose error
