@@ -15,9 +15,9 @@ import json
 import logging
 import os
 import sys
-from datetime import datetime, timedelta, timezone
+from datetime import UTC, datetime, timedelta
 from pathlib import Path
-from typing import Any, Dict, List, Optional
+from typing import Any
 
 import requests
 
@@ -37,7 +37,7 @@ class ReleaseMonitor:
     HOMEBREW_TAP_REPO = "ScottRyanHoward/homebrew-riveter"
     SUPPORTED_PLATFORMS = ["macos-intel", "macos-arm64", "linux-x86_64"]
 
-    def __init__(self, github_token: Optional[str] = None, debug: bool = False):
+    def __init__(self, github_token: str | None = None, debug: bool = False):
         """Initialize the release monitor.
 
         Args:
@@ -65,7 +65,7 @@ class ReleaseMonitor:
         if self.github_token:
             self.headers["Authorization"] = f"token {self.github_token}"
 
-    def get_release_info(self, version: Optional[str] = None) -> Dict[str, Any]:
+    def get_release_info(self, version: str | None = None) -> dict[str, Any]:
         """Get release information from GitHub API.
 
         Args:
@@ -96,7 +96,7 @@ class ReleaseMonitor:
         except requests.RequestException as e:
             raise RuntimeError(f"Failed to fetch release info: {e}") from e
 
-    def get_download_stats(self, version: Optional[str] = None) -> Dict[str, Any]:
+    def get_download_stats(self, version: str | None = None) -> dict[str, Any]:
         """Get download statistics for a release.
 
         Args:
@@ -151,7 +151,7 @@ class ReleaseMonitor:
             logger.error(f"Failed to get download stats: {e}")
             return {}
 
-    def save_download_stats(self, stats: Dict[str, Any]) -> None:
+    def save_download_stats(self, stats: dict[str, Any]) -> None:
         """Save download statistics to file.
 
         Args:
@@ -161,11 +161,11 @@ class ReleaseMonitor:
             # Load existing stats
             existing_stats = []
             if self.stats_file.exists():
-                with open(self.stats_file, "r") as f:
+                with open(self.stats_file) as f:
                     existing_stats = json.load(f)
 
             # Add timestamp
-            stats["collected_at"] = datetime.now(timezone.utc).isoformat()
+            stats["collected_at"] = datetime.now(UTC).isoformat()
 
             # Append new stats
             existing_stats.append(stats)
@@ -183,7 +183,7 @@ class ReleaseMonitor:
         except Exception as e:
             logger.error(f"Failed to save download stats: {e}")
 
-    def get_workflow_runs(self, workflow_name: str, days: int = 7) -> List[Dict[str, Any]]:
+    def get_workflow_runs(self, workflow_name: str, days: int = 7) -> list[dict[str, Any]]:
         """Get recent workflow runs for monitoring.
 
         Args:
@@ -193,7 +193,7 @@ class ReleaseMonitor:
         Returns:
             List of workflow run information
         """
-        since_date = (datetime.now(timezone.utc) - timedelta(days=days)).isoformat()
+        since_date = (datetime.now(UTC) - timedelta(days=days)).isoformat()
 
         url = f"https://api.github.com/repos/{self.GITHUB_REPO}/actions/workflows/{workflow_name}/runs"
         params = {"per_page": 50, "created": f">={since_date}"}
@@ -211,7 +211,7 @@ class ReleaseMonitor:
             logger.error(f"Failed to fetch workflow runs: {e}")
             return []
 
-    def check_build_status(self, days: int = 7) -> Dict[str, Any]:
+    def check_build_status(self, days: int = 7) -> dict[str, Any]:
         """Check the status of recent binary builds.
 
         Args:
@@ -228,7 +228,7 @@ class ReleaseMonitor:
 
         status = {
             "period_days": days,
-            "checked_at": datetime.now(timezone.utc).isoformat(),
+            "checked_at": datetime.now(UTC).isoformat(),
             "binary_builds": {
                 "total": len(binary_runs),
                 "successful": 0,
@@ -295,7 +295,7 @@ class ReleaseMonitor:
 
         return status
 
-    def save_build_status(self, status: Dict[str, Any]) -> None:
+    def save_build_status(self, status: dict[str, Any]) -> None:
         """Save build status to file.
 
         Args:
@@ -305,7 +305,7 @@ class ReleaseMonitor:
             # Load existing status logs
             existing_logs = []
             if self.build_log_file.exists():
-                with open(self.build_log_file, "r") as f:
+                with open(self.build_log_file) as f:
                     existing_logs = json.load(f)
 
             # Append new status
@@ -324,14 +324,14 @@ class ReleaseMonitor:
         except Exception as e:
             logger.error(f"Failed to save build status: {e}")
 
-    def generate_dashboard_data(self) -> Dict[str, Any]:
+    def generate_dashboard_data(self) -> dict[str, Any]:
         """Generate dashboard data combining stats and build status.
 
         Returns:
             Dashboard data dictionary
         """
         dashboard = {
-            "generated_at": datetime.now(timezone.utc).isoformat(),
+            "generated_at": datetime.now(UTC).isoformat(),
             "download_stats": {},
             "build_status": {},
             "alerts": [],
@@ -340,14 +340,14 @@ class ReleaseMonitor:
         try:
             # Get latest download stats
             if self.stats_file.exists():
-                with open(self.stats_file, "r") as f:
+                with open(self.stats_file) as f:
                     stats_history = json.load(f)
                     if stats_history:
                         dashboard["download_stats"] = stats_history[-1]
 
             # Get latest build status
             if self.build_log_file.exists():
-                with open(self.build_log_file, "r") as f:
+                with open(self.build_log_file) as f:
                     build_history = json.load(f)
                     if build_history:
                         dashboard["build_status"] = build_history[-1]
@@ -413,7 +413,7 @@ class ReleaseMonitor:
 
         return dashboard
 
-    def send_alert(self, webhook_url: str, alert_data: Dict[str, Any]) -> bool:
+    def send_alert(self, webhook_url: str, alert_data: dict[str, Any]) -> bool:
         """Send alert to webhook (Slack, Discord, etc.).
 
         Args:
