@@ -5,7 +5,7 @@ import re
 import sys
 import time
 from pathlib import Path
-from typing import Any, Dict, List
+from typing import Any
 
 # Add src to path for imports
 sys.path.insert(0, str(Path(__file__).parent.parent / "src"))
@@ -21,7 +21,7 @@ class RegexOptimizer:
         self.rule_pack_manager = RulePackManager()
         self.optimization_suggestions = []
 
-    def analyze_all_rule_packs(self) -> Dict[str, Any]:
+    def analyze_all_rule_packs(self) -> dict[str, Any]:
         """Analyze regex patterns in all new rule packs."""
         print("🔍 Analyzing Regex Patterns in New Rule Packs")
         print("=" * 50)
@@ -52,7 +52,7 @@ class RegexOptimizer:
                 self._print_pack_summary(pack_name, pack_results)
 
             except Exception as e:
-                print(f"  ❌ Error analyzing {pack_name}: {str(e)}")
+                print(f"  ❌ Error analyzing {pack_name}: {e!s}")
                 analysis_results[pack_name] = {"error": str(e)}
 
         # Print overall summary
@@ -60,7 +60,7 @@ class RegexOptimizer:
 
         return analysis_results
 
-    def analyze_rule_pack(self, pack_name: str) -> Dict[str, Any]:
+    def analyze_rule_pack(self, pack_name: str) -> dict[str, Any]:
         """Analyze regex patterns in a specific rule pack."""
         rule_pack = self.rule_pack_manager.load_rule_pack(pack_name)
 
@@ -96,8 +96,8 @@ class RegexOptimizer:
         return pack_results
 
     def _extract_regex_patterns(
-        self, assert_conditions: Dict[str, Any], rule_id: str
-    ) -> List[Dict[str, Any]]:
+        self, assert_conditions: dict[str, Any], rule_id: str
+    ) -> list[dict[str, Any]]:
         """Extract regex patterns from rule assertion conditions."""
         patterns = []
 
@@ -118,7 +118,7 @@ class RegexOptimizer:
         extract_recursive(assert_conditions)
         return patterns
 
-    def _analyze_pattern(self, pattern_info: Dict[str, Any], rule_id: str) -> Dict[str, Any]:
+    def _analyze_pattern(self, pattern_info: dict[str, Any], rule_id: str) -> dict[str, Any]:
         """Analyze a single regex pattern for performance and correctness."""
         pattern = pattern_info["pattern"]
 
@@ -177,7 +177,7 @@ class RegexOptimizer:
             analysis["issues"] = self._identify_pattern_issues(pattern)
 
         except re.error as e:
-            analysis["issues"].append(f"Invalid regex: {str(e)}")
+            analysis["issues"].append(f"Invalid regex: {e!s}")
             analysis["performance_risk"] = "high"
 
         return analysis
@@ -206,7 +206,7 @@ class RegexOptimizer:
 
         return score
 
-    def _identify_pattern_issues(self, pattern: str) -> List[str]:
+    def _identify_pattern_issues(self, pattern: str) -> list[str]:
         """Identify potential issues in regex patterns."""
         issues = []
 
@@ -233,7 +233,7 @@ class RegexOptimizer:
 
         return issues
 
-    def _generate_optimization_suggestions(self, analysis: Dict[str, Any]) -> List[Dict[str, Any]]:
+    def _generate_optimization_suggestions(self, analysis: dict[str, Any]) -> list[dict[str, Any]]:
         """Generate optimization suggestions for a pattern."""
         suggestions = []
         pattern = analysis["pattern"]
@@ -276,7 +276,7 @@ class RegexOptimizer:
 
         return suggestions
 
-    def _print_pack_summary(self, pack_name: str, results: Dict[str, Any]) -> None:
+    def _print_pack_summary(self, pack_name: str, results: dict[str, Any]) -> None:
         """Print summary for a single rule pack."""
         if "error" in results:
             print(f"  ❌ Error: {results['error']}")
@@ -288,7 +288,7 @@ class RegexOptimizer:
         print(f"  ⚠️  Performance issues: {len(results['performance_issues'])}")
         print(f"  💡 Optimization suggestions: {len(results['optimization_suggestions'])}")
 
-    def _print_overall_summary(self, analysis_results: Dict[str, Any]) -> None:
+    def _print_overall_summary(self, analysis_results: dict[str, Any]) -> None:
         """Print overall analysis summary."""
         print("\n" + "=" * 50)
         print("📊 OVERALL REGEX ANALYSIS SUMMARY")
@@ -361,7 +361,7 @@ class RegexOptimizer:
                 print(f"  • {stype.title()}: {count} suggestions")
 
     def generate_optimization_report(
-        self, analysis_results: Dict[str, Any], output_file: str = None
+        self, analysis_results: dict[str, Any], output_file: str = None
     ) -> str:
         """Generate detailed optimization report."""
         report_lines = ["# Regex Pattern Optimization Report", "", "## Summary", ""]
@@ -447,7 +447,7 @@ def main():
             optimizer.generate_optimization_report(results, args.report)
 
     except Exception as e:
-        print(f"\n❌ Analysis failed: {str(e)}")
+        print(f"\n❌ Analysis failed: {e!s}")
         sys.exit(1)
 
 
