@@ -22,7 +22,6 @@ import sys
 import time
 from dataclasses import dataclass
 from pathlib import Path
-from typing import Dict, List, Optional
 
 try:
     import tomllib
@@ -50,18 +49,18 @@ class VersionConsistencyReport:
     """Report on version consistency across components."""
 
     pyproject_version: str
-    binary_version: Optional[str]
-    formula_version: Optional[str]
+    binary_version: str | None
+    formula_version: str | None
     is_consistent: bool
-    discrepancies: List[str]
-    recommended_actions: List[str]
+    discrepancies: list[str]
+    recommended_actions: list[str]
 
 
 class VersionSynchronizer:
     """Handles version synchronization across all Riveter distribution methods."""
 
     def __init__(
-        self, project_root: Path, debug: bool = False, homebrew_repo_path: Optional[Path] = None
+        self, project_root: Path, debug: bool = False, homebrew_repo_path: Path | None = None
     ):
         """Initialize the version synchronizer.
 
@@ -107,7 +106,7 @@ class VersionSynchronizer:
         except (FileNotFoundError, ValueError) as e:
             raise RuntimeError(f"Failed to read version from pyproject.toml: {e}") from e
 
-    def get_binary_version(self) -> Optional[str]:
+    def get_binary_version(self) -> str | None:
         """Get version from built binary if it exists.
 
         Returns:
@@ -141,8 +140,7 @@ class VersionSynchronizer:
                 version = version_match.group(1)
                 logger.debug(f"Found version in binary: {version}")
                 return version
-            else:
-                raise RuntimeError(f"Could not parse version from binary output: {result.stdout}")
+            raise RuntimeError(f"Could not parse version from binary output: {result.stdout}")
 
         except subprocess.TimeoutExpired as e:
             raise RuntimeError("Binary version check timed out") from e
@@ -151,7 +149,7 @@ class VersionSynchronizer:
         except Exception as e:
             raise RuntimeError(f"Failed to get binary version: {e}") from e
 
-    def get_formula_version(self) -> Optional[str]:
+    def get_formula_version(self) -> str | None:
         """Get version from Homebrew formula if it exists.
 
         Returns:
@@ -167,7 +165,7 @@ class VersionSynchronizer:
         logger.debug(f"Reading version from formula at {self.formula_path}")
 
         try:
-            with open(self.formula_path, "r") as f:
+            with open(self.formula_path) as f:
                 content = f.read()
 
             # Look for version line in Ruby formula
@@ -176,15 +174,13 @@ class VersionSynchronizer:
                 version = version_match.group(1)
                 logger.debug(f"Found version in formula: {version}")
                 return version
-            else:
-                # Also check URL for version (fallback)
-                url_match = re.search(r"/v(\d+\.\d+\.\d+)/", content)
-                if url_match:
-                    version = url_match.group(1)
-                    logger.debug(f"Found version in formula URL: {version}")
-                    return version
-                else:
-                    raise RuntimeError("Could not find version in Homebrew formula")
+            # Also check URL for version (fallback)
+            url_match = re.search(r"/v(\d+\.\d+\.\d+)/", content)
+            if url_match:
+                version = url_match.group(1)
+                logger.debug(f"Found version in formula URL: {version}")
+                return version
+            raise RuntimeError("Could not find version in Homebrew formula")
 
         except Exception as e:
             raise RuntimeError(f"Failed to read version from formula: {e}") from e
@@ -324,7 +320,7 @@ class VersionSynchronizer:
             logger.debug(f"Checking PyInstaller spec file: {spec_file}")
 
             try:
-                with open(spec_file, "r") as f:
+                with open(spec_file) as f:
                     content = f.read()
 
                 # Update version in spec file if hardcoded
@@ -359,7 +355,7 @@ class VersionSynchronizer:
             logger.debug(f"Checking build script: {script_path}")
 
             try:
-                with open(script_path, "r") as f:
+                with open(script_path) as f:
                     content = f.read()
 
                 # Update hardcoded versions in build scripts
@@ -385,7 +381,7 @@ class VersionSynchronizer:
             return
 
         try:
-            with open(cli_path, "r") as f:
+            with open(cli_path) as f:
                 content = f.read()
 
             # Check if CLI uses importlib.metadata for version
@@ -429,8 +425,8 @@ class VersionSynchronizer:
             raise RuntimeError(f"Failed to calculate SHA256 checksum: {e}") from e
 
     def calculate_release_checksums(
-        self, version: str, release_dir: Optional[Path] = None
-    ) -> Dict[str, str]:
+        self, version: str, release_dir: Path | None = None
+    ) -> dict[str, str]:
         """Calculate checksums for all release artifacts.
 
         Args:
@@ -482,7 +478,7 @@ class VersionSynchronizer:
         return checksums
 
     def validate_checksums(
-        self, expected_checksums: Dict[str, str], version: str, release_dir: Optional[Path] = None
+        self, expected_checksums: dict[str, str], version: str, release_dir: Path | None = None
     ) -> bool:
         """Validate that calculated checksums match expected values.
 
@@ -517,7 +513,7 @@ class VersionSynchronizer:
         return all_valid
 
     def update_homebrew_formula(
-        self, version: str, checksums: Optional[Dict[str, str]] = None
+        self, version: str, checksums: dict[str, str] | None = None
     ) -> None:
         """Update Homebrew formula with the specified version and checksums.
 
@@ -550,7 +546,7 @@ class VersionSynchronizer:
             raise RuntimeError(f"Failed to update Homebrew formula: {e}") from e
 
     def _generate_formula_content(
-        self, version: str, checksums: Optional[Dict[str, str]] = None
+        self, version: str, checksums: dict[str, str] | None = None
     ) -> str:
         """Generate Homebrew formula content with the specified version.
 
@@ -569,6 +565,9 @@ class VersionSynchronizer:
                 "linux-x86_64": "PLACEHOLDER_CHECKSUM_LINUX_X86_64",
             }
 
+        # Get source archive checksum for rule packs
+        source_checksum = checksums.get("source", "PLACEHOLDER_SOURCE_CHECKSUM")
+
         formula_template = f"""class Riveter < Formula
   desc "Infrastructure Rule Enforcement as Code for Terraform configurations"
   homepage "https://github.com/riveter/riveter"
@@ -586,8 +585,18 @@ class VersionSynchronizer:
     sha256 "{checksums.get('linux-x86_64', 'PLACEHOLDER_CHECKSUM_LINUX_X86_64')}"
   end
 
+  resource "rule_packs" do
+    url "https://github.com/ScottRyanHoward/riveter/archive/v{version}.tar.gz"
+    sha256 "{source_checksum}"
+  end
+
   def install
     bin.install "riveter"
+
+    # Install rule packs
+    resource("rule_packs").stage do
+      (share/"riveter/rule_packs").install Dir["rule_packs/*.yml"]
+    end
   end
 
   test do
@@ -597,13 +606,16 @@ class VersionSynchronizer:
     # Test that help command works and contains expected content
     help_output = shell_output("#{{bin}}/riveter --help")
     assert_match "Infrastructure Rule Enforcement", help_output
+
+    # Test that rule packs are installed
+    assert_predicate share/"riveter/rule_packs/aws-security.yml", :exist?
   end
 end
 """
 
         return formula_template
 
-    def sync_all_versions(self, checksums: Optional[Dict[str, str]] = None) -> None:
+    def sync_all_versions(self, checksums: dict[str, str] | None = None) -> None:
         """Synchronize all component versions to match pyproject.toml.
 
         Args:
@@ -682,7 +694,7 @@ end
 
             raise
 
-    def create_backup(self) -> Dict[str, Path]:
+    def create_backup(self) -> dict[str, Path]:
         """Create backup of files before synchronization.
 
         Returns:
@@ -727,7 +739,7 @@ end
         except Exception as e:
             raise RuntimeError(f"Failed to create backup: {e}") from e
 
-    def rollback_changes(self, backups: Optional[Dict[str, Path]] = None) -> None:
+    def rollback_changes(self, backups: dict[str, Path] | None = None) -> None:
         """Rollback version synchronization changes.
 
         Args:
@@ -811,7 +823,7 @@ end
             raise RuntimeError(f"Git rollback failed: {e}") from e
 
 
-def parse_checksums(checksums_str: str) -> Dict[str, str]:
+def parse_checksums(checksums_str: str) -> dict[str, str]:
     """Parse checksums string into dictionary.
 
     Args:
