@@ -29,18 +29,17 @@ import sys
 import tempfile
 import urllib.request
 from pathlib import Path
-from typing import Dict, List, Optional
 
 
 class FormulaValidator:
     """Validates Homebrew formula for Riveter."""
 
-    def __init__(self, formula_path: str, version: Optional[str] = None, verbose: bool = False):
+    def __init__(self, formula_path: str, version: str | None = None, verbose: bool = False):
         self.formula_path = Path(formula_path)
         self.version = version
         self.verbose = verbose
-        self.errors: List[str] = []
-        self.warnings: List[str] = []
+        self.errors: list[str] = []
+        self.warnings: list[str] = []
 
     def log(self, message: str, level: str = "INFO") -> None:
         """Log a message with optional verbosity control."""
@@ -79,15 +78,18 @@ class FormulaValidator:
 
         try:
             result = subprocess.run(
-                ["ruby", "-c", str(self.formula_path)], capture_output=True, text=True, timeout=30
+                ["ruby", "-c", str(self.formula_path)],
+                capture_output=True,
+                text=True,
+                timeout=30,
+                check=False,
             )
 
             if result.returncode == 0:
                 self.log("Ruby syntax is valid", "SUCCESS")
                 return True
-            else:
-                self.add_error(f"Ruby syntax error: {result.stderr.strip()}")
-                return False
+            self.add_error(f"Ruby syntax error: {result.stderr.strip()}")
+            return False
 
         except subprocess.TimeoutExpired:
             self.add_error("Ruby syntax check timed out")
@@ -172,7 +174,7 @@ class FormulaValidator:
 
         return structure_valid
 
-    def extract_formula_info(self) -> Optional[Dict]:
+    def extract_formula_info(self) -> dict | None:
         """Extract version, URLs, and checksums from the formula."""
         self.log("Extracting formula information...")
 
@@ -220,7 +222,7 @@ class FormulaValidator:
         self.log(f"Extracted formula info for version {formula_version}", "SUCCESS")
         return info
 
-    def validate_version_consistency(self, formula_info: Dict) -> bool:
+    def validate_version_consistency(self, formula_info: dict) -> bool:
         """Validate version consistency."""
         self.log("Validating version consistency...")
 
@@ -232,8 +234,7 @@ class FormulaValidator:
                     f"Version mismatch: expected {self.version}, found {formula_version}"
                 )
                 return False
-            else:
-                self.log(f"Version matches expected: {self.version}", "SUCCESS")
+            self.log(f"Version matches expected: {self.version}", "SUCCESS")
 
         # Check that URLs contain the correct version
         for platform, info in formula_info["platforms"].items():
@@ -245,7 +246,7 @@ class FormulaValidator:
         self.log("Version consistency validated", "SUCCESS")
         return True
 
-    def download_and_verify_assets(self, formula_info: Dict) -> bool:
+    def download_and_verify_assets(self, formula_info: dict) -> bool:
         """Download and verify binary assets."""
         self.log("Downloading and verifying binary assets...")
 
@@ -325,12 +326,11 @@ class FormulaValidator:
         for element, pattern in required_elements.items():
             if re.search(pattern, install_content):
                 self.log(f"Found install element: {element}", "SUCCESS")
+            elif element == "chmod":
+                self.add_warning(f"Install method missing recommended element: {element}")
             else:
-                if element == "chmod":
-                    self.add_warning(f"Install method missing recommended element: {element}")
-                else:
-                    self.add_error(f"Install method missing required element: {element}")
-                    install_valid = False
+                self.add_error(f"Install method missing required element: {element}")
+                install_valid = False
 
         return install_valid
 
@@ -365,12 +365,11 @@ class FormulaValidator:
         for test_name, pattern in required_tests.items():
             if re.search(pattern, test_content):
                 self.log(f"Found test: {test_name}", "SUCCESS")
+            elif test_name == "version_test":
+                self.add_error(f"Test method missing required test: {test_name}")
+                test_valid = False
             else:
-                if test_name == "version_test":
-                    self.add_error(f"Test method missing required test: {test_name}")
-                    test_valid = False
-                else:
-                    self.add_warning(f"Test method missing recommended test: {test_name}")
+                self.add_warning(f"Test method missing recommended test: {test_name}")
 
         return test_valid
 
