@@ -14,7 +14,7 @@ import time
 from dataclasses import dataclass
 from enum import Enum
 from pathlib import Path
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any
 
 import requests
 
@@ -43,7 +43,7 @@ class ValidationResult:
     passed: bool
     message: str
     severity: ErrorSeverity
-    details: Optional[Dict[str, Any]] = None
+    details: dict[str, Any] | None = None
 
 
 @dataclass
@@ -59,20 +59,20 @@ class RetryConfig:
 class WorkflowErrorHandler:
     """Enhanced error handling for release workflow operations."""
 
-    def __init__(self, project_root: Optional[Path] = None):
+    def __init__(self, project_root: Path | None = None):
         """Initialize error handler.
 
         Args:
             project_root: Path to project root directory.
         """
         self.project_root = project_root or Path.cwd()
-        self.validation_results: List[ValidationResult] = []
+        self.validation_results: list[ValidationResult] = []
 
     def log_error(
         self,
         message: str,
         severity: ErrorSeverity = ErrorSeverity.ERROR,
-        details: Optional[Dict[str, Any]] = None,
+        details: dict[str, Any] | None = None,
     ) -> None:
         """Log error with GitHub Actions formatting.
 
@@ -314,7 +314,7 @@ class WorkflowErrorHandler:
 
     def retry_with_backoff(
         self, operation, retry_config: RetryConfig, operation_name: str
-    ) -> Tuple[bool, Any, Optional[Exception]]:
+    ) -> tuple[bool, Any, Exception | None]:
         """Execute operation with retry logic and backoff.
 
         Args:
@@ -393,7 +393,7 @@ class WorkflowErrorHandler:
                 if response.status_code >= 400:
                     failed_services.append(f"{service_name}: HTTP {response.status_code}")
             except requests.RequestException as e:
-                failed_services.append(f"{service_name}: {str(e)}")
+                failed_services.append(f"{service_name}: {e!s}")
 
         if failed_services:
             return ValidationResult(
