@@ -9,7 +9,7 @@ import zipfile
 from dataclasses import asdict, dataclass, field
 from datetime import datetime
 from pathlib import Path
-from typing import Any, Dict, List, Optional
+from typing import Any
 
 import yaml
 from cryptography.hazmat.primitives import hashes, serialization
@@ -23,7 +23,7 @@ from cryptography.hazmat.primitives.serialization import (
 )
 
 from .exceptions import RiveterError
-from .rule_packs import RulePack, RulePackMetadata
+from .rule_packs import RulePack
 
 
 class RulePackageError(RiveterError):
@@ -40,38 +40,38 @@ class RulePackageManifest:
     author: str
     created: str
     updated: str
-    dependencies: List[str]
-    tags: List[str]
+    dependencies: list[str]
+    tags: list[str]
     min_riveter_version: str
 
     # Package-specific metadata
     package_format: str = "zip"  # zip or tar.gz
     checksum: str = ""
     signature: str = ""
-    file_list: List[str] = field(default_factory=list)
+    file_list: list[str] = field(default_factory=list)
     size_bytes: int = 0
 
     @classmethod
-    def from_rule_pack_metadata(cls, metadata: RulePackMetadata) -> "RulePackageManifest":
-        """Create a package manifest from rule pack metadata."""
+    def from_rule_pack(cls, rule_pack: RulePack) -> "RulePackageManifest":
+        """Create a package manifest from rule pack."""
         return cls(
-            name=metadata.name,
-            version=metadata.version,
-            description=metadata.description,
-            author=metadata.author,
-            created=metadata.created,
-            updated=metadata.updated,
-            dependencies=metadata.dependencies,
-            tags=metadata.tags,
-            min_riveter_version=metadata.min_riveter_version,
+            name=rule_pack.name,
+            version=rule_pack.version,
+            description=rule_pack.description,
+            author=rule_pack.author,
+            created="",  # Not available in RulePack
+            updated="",  # Not available in RulePack
+            dependencies=[],  # Not available in RulePack
+            tags=rule_pack.tags,
+            min_riveter_version="0.1.0",  # Default value
         )
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         """Convert manifest to dictionary."""
         return asdict(self)
 
     @classmethod
-    def from_dict(cls, data: Dict[str, Any]) -> "RulePackageManifest":
+    def from_dict(cls, data: dict[str, Any]) -> "RulePackageManifest":
         """Create manifest from dictionary."""
         return cls(**data)
 
@@ -79,7 +79,7 @@ class RulePackageManifest:
 class RulePackageBuilder:
     """Builder for creating rule packages with versioning and signatures."""
 
-    def __init__(self, private_key: Optional[RSAPrivateKey] = None):
+    def __init__(self, private_key: RSAPrivateKey | None = None):
         """Initialize package builder with optional signing key."""
         self.private_key = private_key
 
@@ -136,8 +136,7 @@ class RulePackageBuilder:
             # Create package
             if package_format == "zip":
                 return self._create_zip_package(temp_path, output_path, manifest)
-            else:
-                return self._create_tar_package(temp_path, output_path, manifest)
+            return self._create_tar_package(temp_path, output_path, manifest)
 
     def _create_readme(self, readme_path: Path, rule_pack: RulePack) -> None:
         """Create a README file for the rule pack."""
@@ -250,7 +249,7 @@ riveter scan --rule-pack {rule_pack.metadata.name} /path/to/terraform
 
     @staticmethod
     def save_private_key(
-        private_key: RSAPrivateKey, file_path: str, password: Optional[str] = None
+        private_key: RSAPrivateKey, file_path: str, password: str | None = None
     ) -> None:
         """Save private key to file."""
         encryption = (
@@ -277,7 +276,7 @@ riveter scan --rule-pack {rule_pack.metadata.name} /path/to/terraform
             f.write(pem)
 
     @staticmethod
-    def load_private_key(file_path: str, password: Optional[str] = None) -> RSAPrivateKey:
+    def load_private_key(file_path: str, password: str | None = None) -> RSAPrivateKey:
         """Load private key from file."""
         with open(file_path, "rb") as f:
             private_key = serialization.load_pem_private_key(
@@ -305,11 +304,11 @@ riveter scan --rule-pack {rule_pack.metadata.name} /path/to/terraform
 class RulePackageValidator:
     """Validator for rule packages with signature verification."""
 
-    def __init__(self, public_key: Optional[RSAPublicKey] = None):
+    def __init__(self, public_key: RSAPublicKey | None = None):
         """Initialize validator with optional public key for signature verification."""
         self.public_key = public_key
 
-    def validate_package(self, package_path: str, verify_signature: bool = True) -> Dict[str, Any]:
+    def validate_package(self, package_path: str, verify_signature: bool = True) -> dict[str, Any]:
         """Validate a rule package and return validation results."""
         result = {
             "valid": False,
@@ -344,7 +343,7 @@ class RulePackageValidator:
                     result["errors"].append("Package missing manifest.json")
                     return result
 
-                with open(manifest_file, "r", encoding="utf-8") as f:
+                with open(manifest_file, encoding="utf-8") as f:
                     manifest_data = json.load(f)
 
                 manifest = RulePackageManifest.from_dict(manifest_data)
@@ -360,12 +359,9 @@ class RulePackageValidator:
                 if verify_signature and manifest.signature:
                     if not self.public_key:
                         result["warnings"].append("Cannot verify signature: no public key provided")
-                    else:
-                        if not self._verify_signature(
-                            temp_path, manifest.signature, self.public_key
-                        ):
-                            result["errors"].append("Package signature verification failed")
-                            return result
+                    elif not self._verify_signature(temp_path, manifest.signature, self.public_key):
+                        result["errors"].append("Package signature verification failed")
+                        return result
 
                 # Load and validate rule pack
                 rules_file = temp_path / "rules.yml"
@@ -373,7 +369,7 @@ class RulePackageValidator:
                     result["errors"].append("Package missing rules.yml")
                     return result
 
-                with open(rules_file, "r", encoding="utf-8") as f:
+                with open(rules_file, encoding="utf-8") as f:
                     rules_data = yaml.safe_load(f)
 
                 # Validate rule pack structure
@@ -399,7 +395,7 @@ class RulePackageValidator:
                 result["valid"] = True
 
         except Exception as e:
-            result["errors"].append(f"Package validation error: {str(e)}")
+            result["errors"].append(f"Package validation error: {e!s}")
 
         return result
 
@@ -459,7 +455,7 @@ class RulePackageRegistry:
     def _load_index(self) -> None:
         """Load package index from file."""
         if self.index_file.exists():
-            with open(self.index_file, "r", encoding="utf-8") as f:
+            with open(self.index_file, encoding="utf-8") as f:
                 self.index = json.load(f)
         else:
             self.index = {"packages": {}, "last_updated": datetime.now().isoformat()}
@@ -491,9 +487,7 @@ class RulePackageRegistry:
 
         self._save_index()
 
-    def get_package_info(
-        self, package_name: str, version: str = "latest"
-    ) -> Optional[Dict[str, Any]]:
+    def get_package_info(self, package_name: str, version: str = "latest") -> dict[str, Any] | None:
         """Get package information from registry."""
         if package_name not in self.index["packages"]:
             return None
@@ -510,7 +504,7 @@ class RulePackageRegistry:
 
         return dict(package_info["versions"][version])
 
-    def list_packages(self) -> List[Dict[str, Any]]:
+    def list_packages(self) -> list[dict[str, Any]]:
         """List all packages in registry."""
         packages = []
 
@@ -533,7 +527,7 @@ class RulePackageRegistry:
 
         return sorted(packages, key=lambda x: x["name"])
 
-    def list_package_versions(self, package_name: str) -> List[str]:
+    def list_package_versions(self, package_name: str) -> list[str]:
         """List all versions of a package."""
         if package_name not in self.index["packages"]:
             return []
@@ -541,7 +535,7 @@ class RulePackageRegistry:
         versions = list(self.index["packages"][package_name]["versions"].keys())
         return sorted(versions, key=self._version_key, reverse=True)
 
-    def remove_package(self, package_name: str, version: Optional[str] = None) -> bool:
+    def remove_package(self, package_name: str, version: str | None = None) -> bool:
         """Remove package or specific version from registry."""
         if package_name not in self.index["packages"]:
             return False
@@ -568,7 +562,7 @@ class RulePackageRegistry:
         self._save_index()
         return True
 
-    def _get_latest_version(self, versions: List[str]) -> str:
+    def _get_latest_version(self, versions: list[str]) -> str:
         """Get the latest version from a list of versions."""
         return max(versions, key=self._version_key)
 
