@@ -3,7 +3,7 @@
 import re
 from dataclasses import dataclass
 from enum import Enum
-from typing import Any, Dict, List, Optional, Set
+from typing import Any
 
 import yaml
 
@@ -25,9 +25,9 @@ class LintIssue:
     rule_id: str
     severity: LintSeverity
     message: str
-    line_number: Optional[int] = None
-    column_number: Optional[int] = None
-    suggestion: Optional[str] = None
+    line_number: int | None = None
+    column_number: int | None = None
+    suggestion: str | None = None
 
 
 @dataclass
@@ -36,7 +36,7 @@ class LintResult:
 
     file_path: str
     valid: bool
-    issues: List[LintIssue]
+    issues: list[LintIssue]
     rule_count: int
 
     @property
@@ -87,7 +87,7 @@ class RuleLinter:
         rule_count = 0
 
         try:
-            with open(file_path, "r", encoding="utf-8") as f:
+            with open(file_path, encoding="utf-8") as f:
                 content = f.read()
                 data = yaml.safe_load(content)
 
@@ -123,7 +123,7 @@ class RuleLinter:
                 LintIssue(
                     rule_id="file",
                     severity=LintSeverity.ERROR,
-                    message=f"Invalid YAML syntax: {str(e)}",
+                    message=f"Invalid YAML syntax: {e!s}",
                 )
             )
         except Exception as e:
@@ -131,7 +131,7 @@ class RuleLinter:
                 LintIssue(
                     rule_id="file",
                     severity=LintSeverity.ERROR,
-                    message=f"Error reading file: {str(e)}",
+                    message=f"Error reading file: {e!s}",
                 )
             )
 
@@ -139,12 +139,12 @@ class RuleLinter:
         return LintResult(file_path, valid, issues, rule_count)
 
     def lint_rule_data(
-        self, rule_data: Dict[str, Any], rule_id: str = "unknown"
-    ) -> List[LintIssue]:
+        self, rule_data: dict[str, Any], rule_id: str = "unknown"
+    ) -> list[LintIssue]:
         """Lint a single rule data dictionary."""
         return self._lint_rule(rule_data, rule_id=rule_id)
 
-    def _check_file_structure(self, data: Dict[str, Any]) -> List[LintIssue]:
+    def _check_file_structure(self, data: dict[str, Any]) -> list[LintIssue]:
         """Check the overall structure of the rule file."""
         issues = []
 
@@ -189,8 +189,8 @@ class RuleLinter:
         return issues
 
     def _lint_rule(
-        self, rule_data: Any, rule_index: Optional[int] = None, rule_id: Optional[str] = None
-    ) -> List[LintIssue]:
+        self, rule_data: Any, rule_index: int | None = None, rule_id: str | None = None
+    ) -> list[LintIssue]:
         """Lint a single rule."""
         issues = []
 
@@ -282,7 +282,7 @@ class RuleLinter:
 
         return issues
 
-    def _validate_rule_id(self, rule_id: Any, context_rule_id: str) -> List[LintIssue]:
+    def _validate_rule_id(self, rule_id: Any, context_rule_id: str) -> list[LintIssue]:
         """Validate rule ID format and content."""
         issues = []
 
@@ -332,7 +332,7 @@ class RuleLinter:
 
         return issues
 
-    def _validate_resource_type(self, resource_type: Any, rule_id: str) -> List[LintIssue]:
+    def _validate_resource_type(self, resource_type: Any, rule_id: str) -> list[LintIssue]:
         """Validate resource type."""
         issues = []
 
@@ -381,7 +381,7 @@ class RuleLinter:
 
         return issues
 
-    def _validate_severity(self, severity: Any, rule_id: str) -> List[LintIssue]:
+    def _validate_severity(self, severity: Any, rule_id: str) -> list[LintIssue]:
         """Validate severity level."""
         issues = []
 
@@ -410,7 +410,7 @@ class RuleLinter:
 
         return issues
 
-    def _validate_description(self, description: Any, rule_id: str) -> List[LintIssue]:
+    def _validate_description(self, description: Any, rule_id: str) -> list[LintIssue]:
         """Validate rule description."""
         issues = []
 
@@ -451,7 +451,7 @@ class RuleLinter:
 
         return issues
 
-    def _validate_filter(self, filter_data: Any, rule_id: str) -> List[LintIssue]:
+    def _validate_filter(self, filter_data: Any, rule_id: str) -> list[LintIssue]:
         """Validate rule filter."""
         issues = []
 
@@ -470,7 +470,7 @@ class RuleLinter:
 
         return issues
 
-    def _validate_assertions(self, assert_data: Any, rule_id: str) -> List[LintIssue]:
+    def _validate_assertions(self, assert_data: Any, rule_id: str) -> list[LintIssue]:
         """Validate rule assertions."""
         issues = []
 
@@ -500,8 +500,8 @@ class RuleLinter:
         return issues
 
     def _validate_conditions(
-        self, conditions: Dict[str, Any], rule_id: str, context: str
-    ) -> List[LintIssue]:
+        self, conditions: dict[str, Any], rule_id: str, context: str
+    ) -> list[LintIssue]:
         """Validate filter or assertion conditions."""
         issues = []
 
@@ -525,8 +525,8 @@ class RuleLinter:
         return issues
 
     def _validate_operator_usage(
-        self, property_path: str, operator_dict: Dict[str, Any], rule_id: str, context: str
-    ) -> List[LintIssue]:
+        self, property_path: str, operator_dict: dict[str, Any], rule_id: str, context: str
+    ) -> list[LintIssue]:
         """Validate operator usage in conditions."""
         issues = []
 
@@ -582,7 +582,7 @@ class RuleLinter:
 
     def _validate_specific_operator(
         self, operator: str, value: Any, property_path: str, rule_id: str, context: str
-    ) -> List[LintIssue]:
+    ) -> list[LintIssue]:
         """Validate specific operator usage."""
         issues = []
 
@@ -606,7 +606,7 @@ class RuleLinter:
                         LintIssue(
                             rule_id=rule_id,
                             severity=LintSeverity.ERROR,
-                            message=f"Invalid regex pattern in {context}.{property_path}: {str(e)}",
+                            message=f"Invalid regex pattern in {context}.{property_path}: {e!s}",
                         )
                     )
 
@@ -679,7 +679,7 @@ class RuleLinter:
 
         return issues
 
-    def _validate_rule_metadata(self, metadata: Any, rule_id: str) -> List[LintIssue]:
+    def _validate_rule_metadata(self, metadata: Any, rule_id: str) -> list[LintIssue]:
         """Validate rule metadata."""
         issues = []
 
@@ -757,7 +757,7 @@ class RuleLinter:
 
         return issues
 
-    def _lint_metadata(self, metadata: Any) -> List[LintIssue]:
+    def _lint_metadata(self, metadata: Any) -> list[LintIssue]:
         """Lint rule pack metadata."""
         issues = []
 
@@ -825,9 +825,9 @@ class RuleLinter:
 
         return issues
 
-    def _check_duplicate_rule_ids(self, data: Dict[str, Any]) -> List[LintIssue]:
+    def _check_duplicate_rule_ids(self, data: dict[str, Any]) -> list[LintIssue]:
         """Check for duplicate rule IDs."""
-        issues: List[LintIssue] = []
+        issues: list[LintIssue] = []
 
         if "rules" not in data or not isinstance(data["rules"], list):
             return issues
@@ -855,7 +855,7 @@ class RuleLinter:
 
         return issues
 
-    def _load_known_resource_types(self) -> Set[str]:
+    def _load_known_resource_types(self) -> set[str]:
         """Load known Terraform resource types."""
         # This is a subset of common resource types
         # In a real implementation, this could be loaded from a comprehensive list
@@ -926,18 +926,17 @@ class RuleTester:
 
     def __init__(self) -> None:
         """Initialize the rule tester."""
-        pass
 
     def test_rule(
-        self, rule_data: Dict[str, Any], test_cases: List[Dict[str, Any]]
-    ) -> Dict[str, Any]:
+        self, rule_data: dict[str, Any], test_cases: list[dict[str, Any]]
+    ) -> dict[str, Any]:
         """Test a rule against sample test cases."""
         from .scanner import validate_resources
 
         try:
             rule = Rule(rule_data)
         except Exception as e:
-            return {"valid": False, "error": f"Failed to create rule: {str(e)}", "test_results": []}
+            return {"valid": False, "error": f"Failed to create rule: {e!s}", "test_results": []}
 
         test_results = []
 
@@ -992,7 +991,7 @@ class RuleTester:
             },
         }
 
-    def create_test_template(self, rule_data: Dict[str, Any]) -> Dict[str, Any]:
+    def create_test_template(self, rule_data: dict[str, Any]) -> dict[str, Any]:
         """Create a test template for a rule."""
         resource_type = rule_data.get("resource_type", "unknown")
 
