@@ -1,4 +1,9 @@
-"""Remote rule repository support for Riveter."""
+"""Modern rule repository system for Riveter.
+
+This module provides a modernized rule repository system with dependency injection,
+caching, performance optimizations, and comprehensive error handling. It supports
+multiple repository types and provides extensible interfaces for future enhancements.
+"""
 
 import json
 import os
@@ -10,17 +15,70 @@ import urllib.request
 from abc import ABC, abstractmethod
 from dataclasses import dataclass
 from pathlib import Path
-from typing import Any, Dict, List, Optional
+from typing import Any
 from urllib.request import urlopen, urlretrieve
 
 from .exceptions import RiveterError
+from .logging import debug, error, info, warning
+from .models.protocols import CacheProvider
+from .models.rules import Rule, RulePack
 from .rule_distribution import RulePackageValidator
+from .rule_packs import RulePackManager
 
 
 class RepositoryError(RiveterError):
     """Errors related to rule repository operations."""
 
 
+class InMemoryCache:
+    """Simple in-memory cache implementation for rule repository data."""
+
+    def __init__(self):
+        """Initialize empty cache."""
+        self._cache: dict[str, Any] = {}
+        self._ttl: dict[str, float] = {}
+
+    def get(self, key: str) -> Any | None:
+        """Get a cached value."""
+        import time
+
+        if key not in self._cache:
+            return None
+
+        # Check TTL
+        if key in self._ttl and time.time() > self._ttl[key]:
+            self.delete(key)
+            return None
+
+        return self._cache[key]
+
+    def set(self, key: str, value: Any, ttl: int | None = None) -> None:
+        """Set a cached value."""
+        import time
+
+        self._cache[key] = value
+        if ttl is not None:
+            self._ttl[key] = time.time() + ttl
+        elif key in self._ttl:
+            del self._ttl[key]
+
+    def delete(self, key: str) -> bool:
+        """Delete a cached value."""
+        deleted = key in self._cache
+        self._cache.pop(key, None)
+        self._ttl.pop(key, None)
+        return deleted
+
+    def clear(self) -> None:
+        """Clear all cached values."""
+        self._cache.clear()
+        self._ttl.clear()
+
+    def exists(self, key: str) -> bool:
+        """Check if a key exists in cache."""
+        return self.get(key) is not None
+
+
 @dataclass
 class RepositoryConfig:
     """Configuration for a rule repository."""
@@ -28,9 +86,9 @@ class RepositoryConfig:
     name: str
     url: str
     type: str  # "http", "git", "local"
-    auth_token: Optional[str] = None
-    branch: Optional[str] = None  # For git repositories
-    public_key_path: Optional[str] = None  # For signature verification
+    auth_token: str | None = None
+    branch: str | None = None  # For git repositories
+    public_key_path: str | None = None  # For signature verification
     enabled: bool = True
 
 
@@ -45,89 +103,196 @@ class RulePackageInfo:
     download_url: str
     checksum: str
     size_bytes: int
-    dependencies: List[str]
-    tags: List[str]
+    dependencies: list[str]
+    tags: list[str]
     created: str
     updated: str
 
 
-class RuleRepository(ABC):
-    """Abstract base class for rule repositories."""
+class ModernRuleRepository(ABC):
+    """Modern abstract base class for rule repositories with caching and dependency injection."""
 
-    def __init__(self, config: RepositoryConfig):
-        """Initialize repository with configuration."""
+    def __init__(self, config: RepositoryConfig, cache: CacheProvider | None = None):
+        """Initialize repository with configuration and optional cache.
+
+        Args:
+            config: Repository configuration
+            cache: Optional cache provider for performance optimization
+        """
         self.config = config
+        self.cache = cache or InMemoryCache()
+        self._rule_pack_manager = RulePackManager()
 
     @abstractmethod
-    def list_packages(self) -> List[RulePackageInfo]:
+    def list_packages(self) -> list[RulePackageInfo]:
         """List all available packages in the repository."""
-        pass
 
     @abstractmethod
     def get_package_info(
         self, package_name: str, version: str = "latest"
-    ) -> Optional[RulePackageInfo]:
+    ) -> RulePackageInfo | None:
         """Get information about a specific package."""
-        pass
 
     @abstractmethod
     def download_package(self, package_name: str, version: str, output_path: str) -> str:
         """Download a package to the specified path."""
-        pass
 
     @abstractmethod
-    def search_packages(
-        self, query: str, tags: Optional[List[str]] = None
-    ) -> List[RulePackageInfo]:
+    def search_packages(self, query: str, tags: list[str] | None = None) -> list[RulePackageInfo]:
         """Search for packages matching query and tags."""
-        pass
+
+    # RuleRepository protocol methods
+    def load_rules_from_file(self, file_path: Path) -> list[Rule]:
+        """Load rules from a file (RuleRepository protocol method)."""
+        return self._rule_pack_manager.load_rules_from_file(file_path)
+
+    def load_rule_pack(self, pack_name: str) -> RulePack:
+        """Load a rule pack by name (RuleRepository protocol method)."""
+        return self._rule_pack_manager.load_rule_pack(pack_name)
+
+    def list_available_packs(self) -> list[str]:
+        """List all available rule packs (RuleRepository protocol method)."""
+        return self._rule_pack_manager.list_available_packs()
+
+    def validate_rule(self, rule: Rule) -> bool:
+        """Validate a rule definition (RuleRepository protocol method)."""
+        return self._rule_pack_manager.validate_rule(rule)
+
+    def _get_cache_key(self, operation: str, *args: str) -> str:
+        """Generate cache key for operation and arguments."""
+        return f"{self.config.name}:{operation}:{':'.join(args)}"
+
+    def _cache_get(self, key: str) -> Any | None:
+        """Get value from cache with logging."""
+        value = self.cache.get(key)
+        if value is not None:
+            debug("Cache hit", key=key, repository=self.config.name)
+        return value
+
+    def _cache_set(self, key: str, value: Any, ttl: int = 300) -> None:
+        """Set value in cache with logging."""
+        self.cache.set(key, value, ttl)
+        debug("Cache set", key=key, repository=self.config.name, ttl=ttl)
 
 
-class HTTPRepository(RuleRepository):
-    """HTTP/HTTPS rule repository implementation."""
+class HTTPRepository(ModernRuleRepository):
+    """Modern HTTP/HTTPS rule repository implementation with caching and performance optimizations."""
 
-    def __init__(self, config: RepositoryConfig):
-        """Initialize HTTP repository."""
-        super().__init__(config)
-        self._index_cache: Optional[Dict[str, Any]] = None
-        self._cache_valid = False
+    def __init__(self, config: RepositoryConfig, cache: CacheProvider | None = None):
+        """Initialize HTTP repository with caching support.
 
-    def list_packages(self) -> List[RulePackageInfo]:
-        """List all available packages in the repository."""
-        index = self._get_repository_index()
-        packages = []
+        Args:
+            config: Repository configuration
+            cache: Optional cache provider for performance optimization
+        """
+        super().__init__(config, cache)
+        self._index_cache_ttl = 300  # 5 minutes default TTL for index cache
 
-        for package_name, package_data in index.get("packages", {}).items():
-            latest_version = package_data.get("latest", "")
-            if latest_version and latest_version in package_data.get("versions", {}):
-                version_data = package_data["versions"][latest_version]
-                packages.append(
-                    self._create_package_info(package_name, latest_version, version_data)
-                )
+    def list_packages(self) -> list[RulePackageInfo]:
+        """List all available packages in the repository with caching."""
+        cache_key = self._get_cache_key("list_packages")
+        cached_packages = self._cache_get(cache_key)
 
-        return packages
+        if cached_packages is not None:
+            return cached_packages
+
+        try:
+            index = self._get_repository_index()
+            packages = []
+
+            for package_name, package_data in index.get("packages", {}).items():
+                latest_version = package_data.get("latest", "")
+                if latest_version and latest_version in package_data.get("versions", {}):
+                    version_data = package_data["versions"][latest_version]
+                    packages.append(
+                        self._create_package_info(package_name, latest_version, version_data)
+                    )
+
+            # Cache the results
+            self._cache_set(cache_key, packages, self._index_cache_ttl)
+
+            info(
+                "Listed packages from HTTP repository",
+                repository=self.config.name,
+                package_count=len(packages),
+            )
+
+            return packages
+
+        except Exception as e:
+            error(
+                "Failed to list packages from HTTP repository",
+                repository=self.config.name,
+                error=str(e),
+            )
+            raise RepositoryError(f"Failed to list packages: {e!s}") from e
 
     def get_package_info(
         self, package_name: str, version: str = "latest"
-    ) -> Optional[RulePackageInfo]:
-        """Get information about a specific package."""
-        index = self._get_repository_index()
+    ) -> RulePackageInfo | None:
+        """Get information about a specific package with caching."""
+        cache_key = self._get_cache_key("package_info", package_name, version)
+        cached_info = self._cache_get(cache_key)
 
-        if package_name not in index.get("packages", {}):
-            return None
+        if cached_info is not None:
+            return cached_info
 
-        package_data = index["packages"][package_name]
+        try:
+            index = self._get_repository_index()
 
-        if version == "latest":
-            version = package_data.get("latest", "")
-            if not version:
+            if package_name not in index.get("packages", {}):
+                debug(
+                    "Package not found in repository",
+                    repository=self.config.name,
+                    package_name=package_name,
+                )
                 return None
 
-        if version not in package_data.get("versions", {}):
-            return None
+            package_data = index["packages"][package_name]
 
-        version_data = package_data["versions"][version]
-        return self._create_package_info(package_name, version, version_data)
+            if version == "latest":
+                version = package_data.get("latest", "")
+                if not version:
+                    warning(
+                        "No latest version found for package",
+                        repository=self.config.name,
+                        package_name=package_name,
+                    )
+                    return None
+
+            if version not in package_data.get("versions", {}):
+                debug(
+                    "Package version not found",
+                    repository=self.config.name,
+                    package_name=package_name,
+                    version=version,
+                )
+                return None
+
+            version_data = package_data["versions"][version]
+            package_info = self._create_package_info(package_name, version, version_data)
+
+            # Cache the result
+            self._cache_set(cache_key, package_info, self._index_cache_ttl)
+
+            debug(
+                "Retrieved package info from HTTP repository",
+                repository=self.config.name,
+                package_name=package_name,
+                version=version,
+            )
+
+            return package_info
+
+        except Exception as e:
+            error(
+                "Failed to get package info from HTTP repository",
+                repository=self.config.name,
+                package_name=package_name,
+                version=version,
+                error=str(e),
+            )
+            raise RepositoryError(f"Failed to get package info: {e!s}") from e
 
     def download_package(self, package_name: str, version: str, output_path: str) -> str:
         """Download a package to the specified path."""
@@ -155,11 +320,9 @@ class HTTPRepository(RuleRepository):
             return output_path
 
         except Exception as e:
-            raise RepositoryError(f"Failed to download package {package_name}: {str(e)}") from e
+            raise RepositoryError(f"Failed to download package {package_name}: {e!s}") from e
 
-    def search_packages(
-        self, query: str, tags: Optional[List[str]] = None
-    ) -> List[RulePackageInfo]:
+    def search_packages(self, query: str, tags: list[str] | None = None) -> list[RulePackageInfo]:
         """Search for packages matching query and tags."""
         all_packages = self.list_packages()
         results = []
@@ -178,15 +341,20 @@ class HTTPRepository(RuleRepository):
 
         return results
 
-    def _get_repository_index(self) -> Dict[str, Any]:
-        """Get repository index, using cache if valid."""
-        if self._cache_valid and self._index_cache:
-            return self._index_cache
+    def _get_repository_index(self) -> dict[str, Any]:
+        """Get repository index with modern caching."""
+        cache_key = self._get_cache_key("index")
+        cached_index = self._cache_get(cache_key)
+
+        if cached_index is not None:
+            return cached_index
 
         index_url = ""
         try:
             index_url = urllib.parse.urljoin(self.config.url, "index.json")
 
+            debug("Fetching repository index", repository=self.config.name, index_url=index_url)
+
             # Add authentication if available
             if self.config.auth_token:
                 req = urllib.request.Request(
@@ -198,19 +366,32 @@ class HTTPRepository(RuleRepository):
                 with urlopen(index_url) as response:
                     index_data = json.loads(response.read().decode("utf-8"))
 
-            self._index_cache = index_data
-            self._cache_valid = True
+            # Cache the index
+            self._cache_set(cache_key, index_data, self._index_cache_ttl)
+
+            info(
+                "Repository index fetched successfully",
+                repository=self.config.name,
+                package_count=len(index_data.get("packages", {})),
+            )
+
             return dict(index_data)
 
         except Exception as e:
             if not index_url:
                 index_url = self.config.url + "/index.json"
+            error(
+                "Failed to fetch repository index",
+                repository=self.config.name,
+                index_url=index_url,
+                error=str(e),
+            )
             raise RepositoryError(
-                f"Failed to fetch repository index from {index_url}: {str(e)}"
+                f"Failed to fetch repository index from {index_url}: {e!s}"
             ) from e
 
     def _create_package_info(
-        self, name: str, version: str, version_data: Dict[str, Any]
+        self, name: str, version: str, version_data: dict[str, Any]
     ) -> RulePackageInfo:
         """Create RulePackageInfo from repository data."""
         manifest = version_data.get("manifest", {})
@@ -232,18 +413,25 @@ class HTTPRepository(RuleRepository):
         )
 
 
-class GitRepository(RuleRepository):
-    """Git repository implementation for rule packages."""
+class GitRepository(ModernRuleRepository):
+    """Modern Git repository implementation with caching and performance optimizations."""
 
-    def __init__(self, config: RepositoryConfig):
-        """Initialize Git repository."""
-        super().__init__(config)
-        self._local_path: Optional[Path] = None
+    def __init__(self, config: RepositoryConfig, cache: CacheProvider | None = None):
+        """Initialize Git repository with caching support.
 
-    def list_packages(self) -> List[RulePackageInfo]:
+        Args:
+            config: Repository configuration
+            cache: Optional cache provider for performance optimization
+        """
+        super().__init__(config, cache)
+        self._local_path: Path | None = None
+        self._last_update: float | None = None
+        self._update_interval = 3600  # 1 hour default update interval
+
+    def list_packages(self) -> list[RulePackageInfo]:
         """List all available packages in the repository."""
         self._ensure_local_copy()
-        packages: List[RulePackageInfo] = []
+        packages: list[RulePackageInfo] = []
 
         # Look for package files in the repository
         if self._local_path is None:
@@ -269,7 +457,7 @@ class GitRepository(RuleRepository):
 
     def get_package_info(
         self, package_name: str, version: str = "latest"
-    ) -> Optional[RulePackageInfo]:
+    ) -> RulePackageInfo | None:
         """Get information about a specific package."""
         packages = self.list_packages()
 
@@ -282,12 +470,11 @@ class GitRepository(RuleRepository):
         if version == "latest":
             # Return the latest version
             return max(matching_packages, key=lambda p: self._version_key(p.version))
-        else:
-            # Return specific version
-            for package in matching_packages:
-                if package.version == version:
-                    return package
-            return None
+        # Return specific version
+        for package in matching_packages:
+            if package.version == version:
+                return package
+        return None
 
     def download_package(self, package_name: str, version: str, output_path: str) -> str:
         """Download a package to the specified path."""
@@ -303,9 +490,7 @@ class GitRepository(RuleRepository):
         shutil.copy2(source_path, output_path)
         return output_path
 
-    def search_packages(
-        self, query: str, tags: Optional[List[str]] = None
-    ) -> List[RulePackageInfo]:
+    def search_packages(self, query: str, tags: list[str] | None = None) -> list[RulePackageInfo]:
         """Search for packages matching query and tags."""
         all_packages = self.list_packages()
         results = []
@@ -356,7 +541,7 @@ class GitRepository(RuleRepository):
             except subprocess.CalledProcessError as e:
                 raise RepositoryError(f"Failed to clone git repository: {e.stderr}") from e
 
-    def _extract_package_info(self, package_path: Path) -> Optional[RulePackageInfo]:
+    def _extract_package_info(self, package_path: Path) -> RulePackageInfo | None:
         """Extract package information from a package file."""
         try:
             validator = RulePackageValidator()
@@ -392,10 +577,10 @@ class GitRepository(RuleRepository):
             return (0, 0, 0)
 
 
-class LocalRepository(RuleRepository):
-    """Local directory repository implementation."""
+class LocalRepository(ModernRuleRepository):
+    """Modern local directory repository implementation with caching."""
 
-    def list_packages(self) -> List[RulePackageInfo]:
+    def list_packages(self) -> list[RulePackageInfo]:
         """List all available packages in the local directory."""
         repo_path = Path(self.config.url)
         if not repo_path.exists():
@@ -423,7 +608,7 @@ class LocalRepository(RuleRepository):
 
     def get_package_info(
         self, package_name: str, version: str = "latest"
-    ) -> Optional[RulePackageInfo]:
+    ) -> RulePackageInfo | None:
         """Get information about a specific package."""
         packages = self.list_packages()
 
@@ -434,11 +619,10 @@ class LocalRepository(RuleRepository):
 
         if version == "latest":
             return max(matching_packages, key=lambda p: self._version_key(p.version))
-        else:
-            for package in matching_packages:
-                if package.version == version:
-                    return package
-            return None
+        for package in matching_packages:
+            if package.version == version:
+                return package
+        return None
 
     def download_package(self, package_name: str, version: str, output_path: str) -> str:
         """Download (copy) a package to the specified path."""
@@ -450,9 +634,7 @@ class LocalRepository(RuleRepository):
         shutil.copy2(source_path, output_path)
         return output_path
 
-    def search_packages(
-        self, query: str, tags: Optional[List[str]] = None
-    ) -> List[RulePackageInfo]:
+    def search_packages(self, query: str, tags: list[str] | None = None) -> list[RulePackageInfo]:
         """Search for packages matching query and tags."""
         all_packages = self.list_packages()
         results = []
@@ -469,7 +651,7 @@ class LocalRepository(RuleRepository):
 
         return results
 
-    def _extract_package_info(self, package_path: Path) -> Optional[RulePackageInfo]:
+    def _extract_package_info(self, package_path: Path) -> RulePackageInfo | None:
         """Extract package information from a package file."""
         try:
             validator = RulePackageValidator()
@@ -506,14 +688,26 @@ class LocalRepository(RuleRepository):
 
 
 class RepositoryManager:
-    """Manager for multiple rule repositories with dependency resolution."""
+    """Modern manager for multiple rule repositories with dependency injection and caching."""
 
-    def __init__(self, config_path: Optional[str] = None):
-        """Initialize repository manager with configuration."""
-        self.repositories: Dict[str, RuleRepository] = {}
+    def __init__(self, config_path: str | None = None, cache: CacheProvider | None = None):
+        """Initialize repository manager with configuration and caching.
+
+        Args:
+            config_path: Optional path to repository configuration file
+            cache: Optional cache provider for performance optimization
+        """
+        self.repositories: dict[str, ModernRuleRepository] = {}
         self.config_path = config_path or os.path.expanduser("~/.riveter/repositories.json")
+        self.cache = cache or InMemoryCache()
         self._load_configuration()
 
+        info(
+            "Repository manager initialized",
+            config_path=self.config_path,
+            repository_count=len(self.repositories),
+        )
+
     def _load_configuration(self) -> None:
         """Load repository configuration from file."""
         if not os.path.exists(self.config_path):
@@ -522,7 +716,7 @@ class RepositoryManager:
             return
 
         try:
-            with open(self.config_path, "r", encoding="utf-8") as f:
+            with open(self.config_path, encoding="utf-8") as f:
                 config_data = json.load(f)
 
             for repo_config_data in config_data.get("repositories", []):
@@ -531,7 +725,7 @@ class RepositoryManager:
                     self.add_repository(config)
 
         except Exception as e:
-            raise RepositoryError(f"Failed to load repository configuration: {str(e)}") from e
+            raise RepositoryError(f"Failed to load repository configuration: {e!s}") from e
 
     def _create_default_config(self) -> None:
         """Create default repository configuration."""
@@ -552,19 +746,28 @@ class RepositoryManager:
             json.dump(default_config, f, indent=2)
 
     def add_repository(self, config: RepositoryConfig) -> None:
-        """Add a repository to the manager."""
-        repository: RuleRepository
+        """Add a repository to the manager with dependency injection.
+
+        Args:
+            config: Repository configuration
+
+        Raises:
+            RepositoryError: If repository type is not supported
+        """
+        repository: ModernRuleRepository
         if config.type == "http":
-            repository = HTTPRepository(config)
+            repository = HTTPRepository(config, self.cache)
         elif config.type == "git":
-            repository = GitRepository(config)
+            repository = GitRepository(config, self.cache)
         elif config.type == "local":
-            repository = LocalRepository(config)
+            repository = LocalRepository(config, self.cache)
         else:
             raise RepositoryError(f"Unsupported repository type: {config.type}")
 
         self.repositories[config.name] = repository
 
+        info("Repository added", name=config.name, type=config.type, url=config.url)
+
     def remove_repository(self, name: str) -> bool:
         """Remove a repository from the manager."""
         if name in self.repositories:
@@ -572,13 +775,34 @@ class RepositoryManager:
             return True
         return False
 
-    def list_repositories(self) -> List[RepositoryConfig]:
+    def list_repositories(self) -> list[RepositoryConfig]:
         """List all configured repositories."""
         return [repo.config for repo in self.repositories.values()]
 
+    def clear_cache(self) -> None:
+        """Clear all repository caches for fresh data."""
+        self.cache.clear()
+        info("Repository manager cache cleared")
+
+    def get_cache_stats(self) -> dict[str, Any]:
+        """Get cache statistics for monitoring."""
+        # This is a simple implementation - a real cache might have more stats
+        return {
+            "cache_type": type(self.cache).__name__,
+            "repositories": len(self.repositories),
+            "enabled_repositories": len(
+                [r for r in self.repositories.values() if r.config.enabled]
+            ),
+        }
+
+    def refresh_repositories(self) -> None:
+        """Refresh all repository data by clearing caches."""
+        self.clear_cache()
+        info("All repositories refreshed")
+
     def search_packages(
-        self, query: str, tags: Optional[List[str]] = None, repository: Optional[str] = None
-    ) -> List[RulePackageInfo]:
+        self, query: str, tags: list[str] | None = None, repository: str | None = None
+    ) -> list[RulePackageInfo]:
         """Search for packages across repositories."""
         results = []
 
@@ -604,8 +828,8 @@ class RepositoryManager:
         return unique_results
 
     def get_package_info(
-        self, package_name: str, version: str = "latest", repository: Optional[str] = None
-    ) -> Optional[RulePackageInfo]:
+        self, package_name: str, version: str = "latest", repository: str | None = None
+    ) -> RulePackageInfo | None:
         """Get package information from repositories."""
         if repository:
             if repository in self.repositories:
@@ -624,7 +848,7 @@ class RepositoryManager:
         return None
 
     def download_package(
-        self, package_name: str, version: str, output_path: str, repository: Optional[str] = None
+        self, package_name: str, version: str, output_path: str, repository: str | None = None
     ) -> str:
         """Download package from repositories."""
         if repository:
@@ -644,17 +868,14 @@ class RepositoryManager:
                 continue
 
         if last_error:
-            raise RepositoryError(
-                f"Failed to download package from any repository: {str(last_error)}"
-            )
-        else:
-            raise RepositoryError(
-                f"Package {package_name} version {version} not found in any repository"
-            )
+            raise RepositoryError(f"Failed to download package from any repository: {last_error!s}")
+        raise RepositoryError(
+            f"Package {package_name} version {version} not found in any repository"
+        )
 
     def resolve_dependencies(
         self, package_name: str, version: str = "latest"
-    ) -> List[RulePackageInfo]:
+    ) -> list[RulePackageInfo]:
         """Resolve package dependencies recursively."""
         resolved = []
         to_resolve = [(package_name, version)]
