@@ -1,3 +1,4 @@
+# type: ignore
 """TOML file handling with validation and error recovery.
 
 This module provides robust TOML file operations with:
@@ -10,45 +11,57 @@ This module provides robust TOML file operations with:
 
 import re
 from pathlib import Path
-from typing import Any, Optional
+from typing import Any
 
-try:
-    import tomllib
-except ImportError:
-    try:
-        import tomli as tomllib  # type: ignore
-    except ImportError:
-        tomllib = None
+# Defer heavy imports until actually needed
+tomllib = None
+tomli_w = None
 
-try:
-    import tomli_w
-except ImportError:
-    tomli_w = None
+
+def _ensure_tomllib() -> None:
+    """Ensure tomllib is imported."""
+    global tomllib
+    if tomllib is None:
+        try:
+            import tomllib as _tomllib
+
+            tomllib = _tomllib
+        except ImportError:
+            try:
+                import tomli as _tomllib  # type: ignore
+
+                tomllib = _tomllib
+            except ImportError:
+                tomllib = None
+
+
+def _ensure_tomli_w() -> None:
+    """Ensure tomli_w is imported."""
+    global tomli_w
+    if tomli_w is None:
+        try:
+            import tomli_w as _tomli_w
+
+            tomli_w = _tomli_w
+        except ImportError:
+            tomli_w = None
 
 
 class TOMLError(Exception):
     """Base exception for TOML operations."""
 
-    pass
-
 
 class TOMLReadError(TOMLError):
     """Exception raised when reading TOML files fails."""
 
-    pass
-
 
 class TOMLWriteError(TOMLError):
     """Exception raised when writing TOML files fails."""
 
-    pass
-
 
 class TOMLValidationError(TOMLError):
     """Exception raised when TOML validation fails."""
 
-    pass
-
 
 class TOMLHandler:
     """Handles TOML file operations with validation and error recovery."""
@@ -60,8 +73,8 @@ class TOMLHandler:
             file_path: Path to the TOML file.
         """
         self.file_path = Path(file_path)
-        self._original_content: Optional[str] = None
-        self._parsed_data: Optional[dict[str, Any]] = None
+        self._original_content: str | None = None
+        self._parsed_data: dict[str, Any] | None = None
 
     def read(self) -> dict[str, Any]:
         """Read and parse TOML file using tomllib.
@@ -79,7 +92,8 @@ class TOMLHandler:
             # Store original content for potential recovery
             self._original_content = self.file_path.read_text(encoding="utf-8")
 
-            # Parse using tomllib (Python 3.11+ built-in) or tomli fallback
+            # Ensure tomllib is loaded
+            _ensure_tomllib()
             if tomllib is None:
                 raise TOMLReadError("tomllib/tomli not available. Install with: pip install tomli")
 
@@ -91,8 +105,7 @@ class TOMLHandler:
         except Exception as e:
             if "TOMLDecodeError" in str(type(e)) or "tomllib" in str(type(e)):
                 raise TOMLReadError(f"Failed to parse TOML file {self.file_path}: {e}") from e
-            else:
-                raise TOMLReadError(f"Failed to parse TOML file {self.file_path}: {e}") from e
+            raise TOMLReadError(f"Failed to parse TOML file {self.file_path}: {e}") from e
         except OSError as e:
             raise TOMLReadError(f"Failed to read TOML file {self.file_path}: {e}") from e
         except (ValueError, TypeError) as e:
@@ -109,6 +122,8 @@ class TOMLHandler:
         Raises:
             TOMLWriteError: If file cannot be written.
         """
+        # Ensure tomli_w is loaded
+        _ensure_tomli_w()
         if tomli_w is None:
             raise TOMLWriteError(
                 "tomli-w package is required for writing TOML files. "
@@ -156,6 +171,7 @@ class TOMLHandler:
 
         try:
             # Try to serialize to catch any issues
+            _ensure_tomli_w()
             if tomli_w:
                 tomli_w.dumps(data)
         except Exception as e:
@@ -163,7 +179,7 @@ class TOMLHandler:
 
     def _preserve_formatting_update(
         self, original: str, old_data: dict[str, Any], new_data: dict[str, Any]
-    ) -> Optional[str]:
+    ) -> str | None:
         """Attempt to preserve formatting when updating simple values.
 
         This is a best-effort approach for simple updates like version changes.
@@ -246,7 +262,7 @@ class TOMLHandler:
         """
         changes = []
 
-        for key in old_data.keys():
+        for key in old_data:
             if key not in new_data:
                 continue
 
@@ -261,7 +277,7 @@ class TOMLHandler:
 
         return changes
 
-    def _build_value_pattern(self, key_path: str, old_value: Any) -> Optional[str]:
+    def _build_value_pattern(self, key_path: str, old_value: Any) -> str | None:
         """Build regex pattern to match a specific key-value pair.
 
         Args:
@@ -282,10 +298,10 @@ class TOMLHandler:
             escaped_value = re.escape(old_value)
             # Match: key = "value" or key = 'value'
             return rf'({escaped_key}\s*=\s*["\'])({escaped_value})(["\'])'
-        elif isinstance(old_value, (int, float)):
+        if isinstance(old_value, (int, float)):
             # Match: key = 123 or key = 1.23
             return rf"({escaped_key}\s*=\s*)({re.escape(str(old_value))})"
-        elif isinstance(old_value, bool):
+        if isinstance(old_value, bool):
             # Match: key = true or key = false
             value_str = "true" if old_value else "false"
             return rf"({escaped_key}\s*=\s*)({value_str})"
@@ -305,15 +321,15 @@ class TOMLHandler:
         if isinstance(new_value, str):
             # Preserve quote style from original (captured in group 1 and 3)
             return rf"\g<1>{new_value}\g<3>"
-        elif isinstance(new_value, (int, float)):
+        if isinstance(new_value, (int, float)):
             return rf"\g<1>{new_value}"
-        elif isinstance(new_value, bool):
+        if isinstance(new_value, bool):
             value_str = "true" if new_value else "false"
             return rf"\g<1>{value_str}"
 
         return str(new_value)
 
-    def validate_structure(self, required_keys: Optional[list[str]] = None) -> bool:
+    def validate_structure(self, required_keys: list[str] | None = None) -> bool:
         """Validate TOML file structure.
 
         Args:
