@@ -5,10 +5,10 @@ import subprocess
 from dataclasses import dataclass
 from enum import Enum
 from pathlib import Path
-from typing import Optional
+from typing import Any, Dict, List, Optional
 
 from riveter.toml_handler import TOMLHandler, TOMLReadError, TOMLValidationError, TOMLWriteError
-from riveter.version import get_version_from_pyproject
+from riveter.version import get_version_from_pyproject, validate_version_format
 
 
 class VersionType(Enum):
@@ -69,14 +69,7 @@ class VersionManager:
         Raises:
             ValueError: If version format is invalid.
         """
-        # Semantic version pattern: MAJOR.MINOR.PATCH with optional pre-release/build metadata
-        pattern = (
-            r"^(\d+)\.(\d+)\.(\d+)"
-            r"(?:-([0-9A-Za-z-]+(?:\.[0-9A-Za-z-]+)*))?"
-            r"(?:\+([0-9A-Za-z-]+(?:\.[0-9A-Za-z-]+)*))?$"
-        )
-
-        if not re.match(pattern, version):
+        if not validate_version_format(version):
             raise ValueError(f"Invalid semantic version format: {version}")
 
     def _parse_version_components(self, version: str) -> tuple[int, int, int]:
@@ -337,3 +330,154 @@ class VersionManager:
         self.create_git_tag(version_info.tag, tag_message)
 
         return version_info
+
+    def get_version_history(self, limit: int = 10) -> List[str]:
+        """Get version history from git tags.
+
+        Args:
+            limit: Maximum number of versions to return
+
+        Returns:
+            List of version tags in reverse chronological order
+
+        Raises:
+            RuntimeError: If git operations fail
+        """
+        try:
+            result = subprocess.run(
+                ["git", "tag", "-l", "--sort=-version:refname", "v*"],
+                cwd=self.project_root,
+                capture_output=True,
+                text=True,
+                check=True,
+                timeout=30,
+            )
+
+            tags = result.stdout.strip().split("\n") if result.stdout.strip() else []
+            return tags[:limit]
+
+        except subprocess.CalledProcessError as e:
+            raise RuntimeError(f"Failed to get version history: {e}") from e
+        except subprocess.TimeoutExpired as e:
+            raise RuntimeError("Git operation timed out while getting version history") from e
+
+    def get_latest_version_tag(self) -> Optional[str]:
+        """Get the latest version tag from git.
+
+        Returns:
+            Latest version tag or None if no tags exist
+
+        Raises:
+            RuntimeError: If git operations fail
+        """
+        try:
+            history = self.get_version_history(limit=1)
+            return history[0] if history else None
+        except RuntimeError:
+            return None
+
+    def is_version_ahead_of_tag(self, version: str) -> bool:
+        """Check if given version is ahead of the latest git tag.
+
+        Args:
+            version: Version string to check
+
+        Returns:
+            True if version is ahead of latest tag
+
+        Raises:
+            RuntimeError: If git operations fail
+        """
+        latest_tag = self.get_latest_version_tag()
+        if not latest_tag:
+            return True  # No tags exist, so any version is ahead
+
+        # Remove 'v' prefix from tag for comparison
+        latest_version = latest_tag[1:] if latest_tag.startswith("v") else latest_tag
+
+        from riveter.version import compare_versions
+
+        try:
+            return compare_versions(version, latest_version) > 0
+        except ValueError:
+            # If comparison fails, assume version is ahead
+            return True
+
+    def suggest_next_version(self, current_version: Optional[str] = None) -> Dict[str, str]:
+        """Suggest next version numbers for different bump types.
+
+        Args:
+            current_version: Current version, reads from pyproject.toml if None
+
+        Returns:
+            Dictionary with suggested versions for each bump type
+
+        Raises:
+            ValueError: If current version is invalid
+        """
+        if current_version is None:
+            current_version = self.read_current_version()
+
+        suggestions = {}
+        for version_type in VersionType:
+            try:
+                suggestions[version_type.value] = self.calculate_next_version(
+                    current_version, version_type
+                )
+            except ValueError as e:
+                suggestions[version_type.value] = f"Error: {e}"
+
+        return suggestions
+
+    def dry_run_version_update(self, version_type: VersionType) -> Dict[str, Any]:
+        """Perform a dry run of version update without making changes.
+
+        Args:
+            version_type: Type of version bump to simulate
+
+        Returns:
+            Dictionary with simulation results
+
+        Raises:
+            ValueError: If version update would fail
+        """
+        try:
+            version_info = self.create_version_info(version_type)
+
+            # Check if tag already exists
+            tag_exists = self.check_tag_exists(version_info.tag)
+
+            # Check if version is ahead of latest tag
+            is_ahead = self.is_version_ahead_of_tag(version_info.new)
+
+            return {
+                "current_version": version_info.current,
+                "new_version": version_info.new,
+                "tag": version_info.tag,
+                "tag_exists": tag_exists,
+                "is_ahead_of_latest": is_ahead,
+                "would_succeed": not tag_exists and is_ahead,
+                "issues": (
+                    []
+                    if not tag_exists and is_ahead
+                    else [
+                        f"Tag {version_info.tag} already exists" if tag_exists else None,
+                        (
+                            f"Version {version_info.new} is not ahead of latest tag"
+                            if not is_ahead
+                            else None
+                        ),
+                    ]
+                ),
+            }
+
+        except Exception as e:
+            return {
+                "current_version": None,
+                "new_version": None,
+                "tag": None,
+                "tag_exists": False,
+                "is_ahead_of_latest": False,
+                "would_succeed": False,
+                "issues": [str(e)],
+            }
