@@ -10,9 +10,9 @@ import subprocess
 from dataclasses import dataclass, field
 from enum import Enum
 from pathlib import Path
-from typing import Dict, List, Optional
+from typing import Any, Dict, List, Optional
 
-from .version import get_version_from_pyproject
+from .version import get_version_from_pyproject, validate_version_format
 
 logger = logging.getLogger(__name__)
 
@@ -183,7 +183,7 @@ class VersionValidator:
                 return
 
             # Validate version format
-            if not self._is_valid_semver(version):
+            if not validate_version_format(version):
                 report.add_issue(
                     ValidationIssue(
                         component="pyproject.toml",
@@ -270,7 +270,7 @@ class VersionValidator:
             return
 
         try:
-            with open(cli_path, "r") as f:
+            with open(cli_path) as f:
                 content = f.read()
 
             # Check for proper version handling
@@ -426,7 +426,7 @@ class VersionValidator:
             return
 
         try:
-            with open(formula_path, "r") as f:
+            with open(formula_path) as f:
                 content = f.read()
 
             # Extract version from formula
@@ -523,7 +523,7 @@ class VersionValidator:
                 continue
 
             try:
-                with open(script_path, "r") as f:
+                with open(script_path) as f:
                     content = f.read()
 
                 # Check for hardcoded versions
@@ -569,7 +569,7 @@ class VersionValidator:
                 continue
 
             try:
-                with open(doc_path, "r") as f:
+                with open(doc_path) as f:
                     content = f.read()
 
                 # Look for version references that might be outdated
@@ -631,15 +631,6 @@ class VersionValidator:
                 )
             )
 
-    def _is_valid_semver(self, version: str) -> bool:
-        """Check if version string is valid semantic version."""
-        pattern = (
-            r"^(\d+)\.(\d+)\.(\d+)"
-            r"(?:-([0-9A-Za-z-]+(?:\.[0-9A-Za-z-]+)*))?"
-            r"(?:\+([0-9A-Za-z-]+(?:\.[0-9A-Za-z-]+)*))?$"
-        )
-        return bool(re.match(pattern, version))
-
     def generate_validation_report(self, report: ValidationReport) -> str:
         """Generate a human-readable validation report.
 
@@ -691,3 +682,151 @@ class VersionValidator:
             lines.append("")
 
         return "\n".join(lines)
+
+    def validate_version_consistency_only(self) -> ValidationReport:
+        """Perform a lightweight validation focusing only on version consistency.
+
+        Returns:
+            ValidationReport with consistency validation results
+        """
+        logger.info("Starting lightweight version consistency validation...")
+
+        try:
+            source_version = get_version_from_pyproject(self.project_root)
+            report = ValidationReport(source_version=source_version)
+
+            # Only validate components that are quick to check
+            self._validate_pyproject_toml(report)
+            self._validate_package_metadata(report)
+            self._validate_version_consistency(report)
+
+            logger.info(f"Lightweight validation completed. Found {len(report.issues)} issues.")
+            return report
+
+        except Exception as e:
+            logger.error(f"Lightweight validation failed: {e}")
+            raise
+
+    def get_version_summary(self) -> Dict[str, Any]:
+        """Get a summary of version information across all components.
+
+        Returns:
+            Dictionary with version summary
+        """
+        try:
+            report = self.validate_all_components()
+
+            summary = {
+                "source_version": report.source_version,
+                "is_consistent": report.is_consistent,
+                "total_components": len(report.components),
+                "components_with_versions": len(
+                    [c for c in report.components.values() if c.version]
+                ),
+                "issues_by_severity": {
+                    severity.value: len(report.get_issues_by_severity(severity))
+                    for severity in ValidationSeverity
+                },
+                "component_versions": {
+                    name: info.version for name, info in report.components.items()
+                },
+            }
+
+            return summary
+
+        except Exception as e:
+            return {
+                "source_version": "unknown",
+                "is_consistent": False,
+                "error": str(e),
+            }
+
+    def check_version_ahead_of_components(self, target_version: str) -> Dict[str, bool]:
+        """Check if target version is ahead of all component versions.
+
+        Args:
+            target_version: Version to check against components
+
+        Returns:
+            Dictionary mapping component names to whether target is ahead
+        """
+        from .version import compare_versions
+
+        report = self.validate_all_components()
+        results = {}
+
+        for name, info in report.components.items():
+            if info.version:
+                try:
+                    is_ahead = compare_versions(target_version, info.version) > 0
+                    results[name] = is_ahead
+                except ValueError:
+                    # If comparison fails, assume not ahead
+                    results[name] = False
+            else:
+                # No version to compare against
+                results[name] = True
+
+        return results
+
+    def suggest_version_fixes(self) -> List[Dict[str, str]]:
+        """Suggest fixes for version inconsistencies.
+
+        Returns:
+            List of suggested fixes with descriptions
+        """
+        report = self.validate_all_components()
+        suggestions = []
+
+        for issue in report.issues:
+            if issue.severity in (ValidationSeverity.ERROR, ValidationSeverity.CRITICAL):
+                suggestion = {
+                    "component": issue.component,
+                    "issue": issue.message,
+                    "fix": issue.suggestion or "Manual intervention required",
+                }
+
+                # Add specific fix suggestions based on component
+                if issue.component == "binary":
+                    suggestion["command"] = "Rebuild binary with: python scripts/build_binary.py"
+                elif issue.component == "homebrew_formula":
+                    suggestion["command"] = (
+                        "Update formula version and run: brew audit --strict riveter"
+                    )
+                elif issue.component == "package_metadata":
+                    suggestion["command"] = "Reinstall package with: pip install -e ."
+
+                suggestions.append(suggestion)
+
+        return suggestions
+
+
+# Global validator instance for convenience
+_global_validator: Optional[VersionValidator] = None
+
+
+def get_version_validator(
+    project_root: Optional[Path] = None, debug: bool = False
+) -> VersionValidator:
+    """Get or create global version validator instance."""
+    global _global_validator
+    if _global_validator is None or _global_validator.project_root != (project_root or Path.cwd()):
+        _global_validator = VersionValidator(project_root or Path.cwd(), debug)
+    return _global_validator
+
+
+def validate_version_consistency(project_root: Optional[Path] = None) -> ValidationReport:
+    """Validate version consistency using global validator."""
+    return get_version_validator(project_root).validate_version_consistency_only()
+
+
+def get_version_summary(project_root: Optional[Path] = None) -> Dict[str, Any]:
+    """Get version summary using global validator."""
+    return get_version_validator(project_root).get_version_summary()
+
+
+def generate_version_report(project_root: Optional[Path] = None) -> str:
+    """Generate human-readable version report using global validator."""
+    validator = get_version_validator(project_root)
+    report = validator.validate_all_components()
+    return validator.generate_validation_report(report)
