@@ -5,12 +5,12 @@ import os
 import subprocess
 import sys
 from pathlib import Path
-from typing import Any, Dict, List
+from typing import Any
 
 import pytest
 
 
-def run_cli_command(args: List[str], **kwargs) -> subprocess.CompletedProcess:
+def run_cli_command(args: list[str], **kwargs) -> subprocess.CompletedProcess:
     """Helper function to run CLI commands with proper environment setup."""
     env = os.environ.copy()
     env["PYTHONPATH"] = str(Path(__file__).parent.parent / "src")
@@ -24,7 +24,7 @@ def run_cli_command(args: List[str], **kwargs) -> subprocess.CompletedProcess:
     )
 
 
-def extract_json_from_output(output: str) -> Dict[str, Any]:
+def extract_json_from_output(output: str) -> dict[str, Any]:
     """Extract JSON from CLI output that may contain informational messages."""
     lines = output.strip().split("\n")
     json_start = -1
@@ -36,8 +36,7 @@ def extract_json_from_output(output: str) -> Dict[str, Any]:
     if json_start >= 0:
         json_output = "\n".join(lines[json_start:])
         return json.loads(json_output)
-    else:
-        raise ValueError(f"No JSON found in output: {output}")
+    raise ValueError(f"No JSON found in output: {output}")
 
 
 class TestListRulePacksCommand:
