@@ -459,7 +459,7 @@ class TestConfigManager:
             # Verify file was created and contains expected content
             assert os.path.exists(config_file)
 
-            with open(config_file, "r") as f:
+            with open(config_file) as f:
                 content = yaml.safe_load(f)
 
             assert "rule_dirs" in content
@@ -483,7 +483,7 @@ class TestConfigManager:
             # Verify file was created and contains expected content
             assert os.path.exists(config_file)
 
-            with open(config_file, "r") as f:
+            with open(config_file) as f:
                 content = json.load(f)
 
             assert "rule_dirs" in content
