@@ -472,16 +472,15 @@ description = "Test project"
                     result.stdout = "2"  # 2 commits behind
                     result.returncode = 0
                     return result
-                elif "status" in args[0]:
+                if "status" in args[0]:
                     result = Mock()
                     result.stdout = ""  # No uncommitted changes
                     result.returncode = 0
                     return result
-                else:
-                    result = Mock()
-                    result.stdout = "main"
-                    result.returncode = 0
-                    return result
+                result = Mock()
+                result.stdout = "main"
+                result.returncode = 0
+                return result
 
             mock_run.side_effect = side_effect
 
@@ -549,6 +548,7 @@ description = "Test project"
                 ],
                 capture_output=True,
                 text=True,
+                check=False,
             )
 
             # In CI, network connectivity might fail, but that's expected
