@@ -3,7 +3,7 @@
 import os
 import tempfile
 import time
-from typing import Any, Dict, List
+from typing import Any
 
 import pytest
 
@@ -26,7 +26,7 @@ class TestNewRulePacksPerformance:
         return PerformanceMetrics()
 
     @pytest.fixture
-    def large_terraform_config(self) -> Dict[str, Any]:
+    def large_terraform_config(self) -> dict[str, Any]:
         """Create a large Terraform configuration for performance testing."""
         resources = []
 
@@ -206,7 +206,7 @@ class TestNewRulePacksPerformance:
                 print(f"✓ {pack_name}: {len(rule_pack.rules)} rules, {scan_time:.3f}s scan time")
 
             except Exception as e:
-                print(f"✗ {pack_name}: Failed - {str(e)}")
+                print(f"✗ {pack_name}: Failed - {e!s}")
                 results[pack_name] = {"error": str(e)}
 
         # Record overall metrics
@@ -272,7 +272,7 @@ class TestNewRulePacksPerformance:
                 print(f"✓ {combo_name}: {len(all_rules)} rules, {scan_time:.3f}s scan time")
 
             except Exception as e:
-                print(f"✗ {combo_name}: Failed - {str(e)}")
+                print(f"✗ {combo_name}: Failed - {e!s}")
                 results[combo_name] = {"error": str(e)}
 
     def test_parallel_processing_performance(
@@ -459,7 +459,7 @@ class TestNewRulePacksPerformance:
                         ), f"Regex execution too slow in {rule.id}: {max_execution_time:.6f}s"
 
                     except re.error as e:
-                        print(f"✗ Invalid regex in {rule.id}: {pattern} - {str(e)}")
+                        print(f"✗ Invalid regex in {rule.id}: {pattern} - {e!s}")
                         regex_performance.append(
                             {
                                 "rule_pack": pack_name,
@@ -580,7 +580,7 @@ class TestNewRulePacksPerformance:
             finally:
                 os.unlink(terraform_file)
 
-    def _extract_regex_patterns(self, assert_conditions: Dict[str, Any]) -> List[Dict[str, str]]:
+    def _extract_regex_patterns(self, assert_conditions: dict[str, Any]) -> list[dict[str, str]]:
         """Extract regex patterns from rule assertion conditions."""
         patterns = []
 
@@ -599,7 +599,7 @@ class TestNewRulePacksPerformance:
         extract_recursive(assert_conditions)
         return patterns
 
-    def _generate_terraform_config(self, resource_count: int) -> Dict[str, Any]:
+    def _generate_terraform_config(self, resource_count: int) -> dict[str, Any]:
         """Generate a Terraform configuration with specified number of resources."""
         resources = []
 
@@ -701,7 +701,7 @@ class TestPerformanceReporting:
         assert "0.5" in report  # scan time
         assert "93.3%" in report  # optimization rate
 
-    def _generate_performance_report(self, benchmark_data: Dict[str, Any]) -> str:
+    def _generate_performance_report(self, benchmark_data: dict[str, Any]) -> str:
         """Generate a formatted performance report."""
         report_lines = [
             "# Riveter New Rule Packs Performance Report",
