@@ -13,7 +13,7 @@ from riveter.rule_distribution import (
     RulePackageRegistry,
     RulePackageValidator,
 )
-from riveter.rule_packs import RulePack, RulePackMetadata
+from riveter.rule_packs import RulePack
 from riveter.rules import Rule
 
 
