@@ -1,6 +1,6 @@
 """Unit tests for the scanner module."""
 
-from riveter.rules import Rule
+from riveter.rules import create_rule_from_dict
 from riveter.scanner import ValidationResult, validate_resources
 
 
@@ -50,7 +50,7 @@ class TestValidateResources:
             "resource_type": "aws_instance",
             "assert": {"tags": {"Environment": "present"}},
         }
-        rule = Rule(rule_dict)
+        rule = create_rule_from_dict(rule_dict)
 
         # Resource with different type
         resources = [
@@ -72,7 +72,7 @@ class TestValidateResources:
             "resource_type": "aws_instance",
             "assert": {"tags": {"Environment": "present"}},
         }
-        rule = Rule(rule_dict)
+        rule = create_rule_from_dict(rule_dict)
 
         resources = [
             {
@@ -97,7 +97,7 @@ class TestValidateResources:
             "resource_type": "aws_instance",
             "assert": {"tags": {"CostCenter": "present"}},
         }
-        rule = Rule(rule_dict)
+        rule = create_rule_from_dict(rule_dict)
 
         resources = [
             {
@@ -120,7 +120,7 @@ class TestValidateResources:
             "resource_type": "aws_instance",
             "assert": {"tags": {"Environment": "production"}},
         }
-        rule = Rule(rule_dict)
+        rule = create_rule_from_dict(rule_dict)
 
         resources = [
             {
@@ -145,7 +145,7 @@ class TestValidateResources:
             "resource_type": "aws_instance",
             "assert": {"instance_type": "t3.micro"},
         }
-        rule = Rule(rule_dict)
+        rule = create_rule_from_dict(rule_dict)
 
         resources = [
             {
@@ -171,7 +171,7 @@ class TestValidateResources:
             "resource_type": "aws_instance",
             "assert": {"instance_type": "t3.micro"},
         }
-        rule = Rule(rule_dict)
+        rule = create_rule_from_dict(rule_dict)
 
         resources = [
             {
@@ -199,7 +199,7 @@ class TestValidateResources:
             "filter": {"tags": {"Environment": "production"}},
             "assert": {"tags": {"CostCenter": "present"}},
         }
-        rule = Rule(rule_dict)
+        rule = create_rule_from_dict(rule_dict)
 
         resources = [
             {
@@ -228,7 +228,7 @@ class TestValidateResources:
             "resource_type": "*",
             "assert": {"tags": {"Environment": "present"}},
         }
-        rule = Rule(rule_dict)
+        rule = create_rule_from_dict(rule_dict)
 
         resources = [
             {
@@ -268,7 +268,7 @@ class TestValidateResources:
             "assert": {"tags": {"CostCenter": "present"}},
         }
 
-        rules = [Rule(rule1_dict), Rule(rule2_dict)]
+        rules = [create_rule_from_dict(rule1_dict), create_rule_from_dict(rule2_dict)]
 
         resources = [
             {
@@ -292,7 +292,7 @@ class TestValidateResources:
             "resource_type": "aws_instance",
             "assert": {"tags": {"Environment": "production", "CostCenter": "present"}},
         }
-        rule = Rule(rule_dict)
+        rule = create_rule_from_dict(rule_dict)
 
         # Resource that passes all assertions
         passing_resource = {
@@ -328,7 +328,7 @@ class TestValidateResources:
             "resource_type": "aws_instance",
             "assert": {"tags": {"Environment": "present"}},
         }
-        rule = Rule(rule_dict)
+        rule = create_rule_from_dict(rule_dict)
 
         resources = [
             {
@@ -375,7 +375,7 @@ class TestAdvancedValidation:
             "severity": "error",
             "assert": {"tags": {"Environment": "present"}},
         }
-        rule = Rule(rule_dict)
+        rule = create_rule_from_dict(rule_dict)
 
         resource = {"id": "test", "resource_type": "aws_instance"}
         assertion_results = [
@@ -404,7 +404,7 @@ class TestAdvancedValidation:
             "resource_type": "aws_instance",
             "assert": {"tags": {"Environment": "present"}},
         }
-        rule = Rule(rule_dict)
+        rule = create_rule_from_dict(rule_dict)
 
         resource = {"id": "test", "resource_type": "aws_instance"}
         assertion_results = [
@@ -438,7 +438,7 @@ class TestAdvancedValidation:
                 "security_groups": {"length": {"gte": 1}},
             },
         }
-        rule = Rule(rule_dict)
+        rule = create_rule_from_dict(rule_dict)
 
         # Resource that passes all assertions
         passing_resource = {
@@ -500,7 +500,11 @@ class TestAdvancedValidation:
             "assert": {"tags": {"Nice": "present"}},
         }
 
-        rules = [Rule(error_rule_dict), Rule(warning_rule_dict), Rule(info_rule_dict)]
+        rules = [
+            create_rule_from_dict(error_rule_dict),
+            create_rule_from_dict(warning_rule_dict),
+            create_rule_from_dict(info_rule_dict),
+        ]
 
         resource = {"id": "test-instance", "resource_type": "aws_instance", "tags": {}}
 
@@ -525,7 +529,7 @@ class TestAdvancedValidation:
         from riveter.scanner import Severity, filter_results_by_severity
 
         # Create rules with different severities
-        error_rule = Rule(
+        error_rule = create_rule_from_dict(
             {
                 "id": "error-rule",
                 "resource_type": "aws_instance",
@@ -534,7 +538,7 @@ class TestAdvancedValidation:
             }
         )
 
-        warning_rule = Rule(
+        warning_rule = create_rule_from_dict(
             {
                 "id": "warning-rule",
                 "resource_type": "aws_instance",
@@ -567,7 +571,7 @@ class TestAdvancedValidation:
             "resource_type": "aws_instance",
             "assert": {"tags": {"Environment": "present"}},
         }
-        rule = Rule(rule_dict)
+        rule = create_rule_from_dict(rule_dict)
 
         resource = {
             "id": "test-instance",
